@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: indexer.cpp,v 1.65 2007/12/20 09:08:04 dockes Exp $ (C) 2004 J.F.Dockes";
+static char rcsid[] = "@(#$Id: indexer.cpp,v 1.70 2008/10/08 16:15:22 dockes Exp $ (C) 2004 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -46,6 +46,7 @@ static char rcsid[] = "@(#$Id: indexer.cpp,v 1.65 2007/12/20 09:08:04 dockes Exp
 #include "internfile.h"
 #include "smallut.h"
 #include "wipedir.h"
+#include "fileudi.h"
 
 #ifdef RCL_USE_ASPELL
 #include "rclaspell.h"
@@ -145,12 +146,13 @@ bool DbIndexer::indexDb(bool resetbefore, list<string> *topdirs)
 		m_dbdir.c_str()));
 	return false;
     }
-    if (!m_missingExternal.empty()) {
-	string missing;
-	stringsToString(m_missingExternal, missing);
-	LOGINFO(("DbIndexer::index missing helper program(s): %s\n", 
+    string missing;
+    FileInterner::getMissingDescription(missing);
+    if (!missing.empty()) {
+	LOGINFO(("DbIndexer::index missing helper program(s):\n%s\n", 
 		 missing.c_str()));
     }
+    m_config->storeMissingHelperDesc(missing);
     return true;
 }
 
@@ -335,7 +337,9 @@ bool DbIndexer::purgeFiles(const list<string> &filenames)
 
     list<string>::const_iterator it;
     for (it = filenames.begin(); it != filenames.end(); it++) {
-	if (!m_db.purgeFile(*it)) {
+	string udi;
+	make_udi(*it, "", udi);
+	if (!m_db.purgeFile(udi)) {
 	    LOGERR(("DbIndexer::purgeFiles: Database error\n"));
 	    return false;
 	}
@@ -386,9 +390,19 @@ DbIndexer::processone(const std::string &fn, const struct stat *stp,
     // from on to off it may happen that some files which are now
     // without mime type will not be purged from the db, resulting
     // in possible 'cannot intern file' messages at query time...
-    if (!m_db.needUpdate(fn, stp)) {
+    char cbuf[100]; 
+    // Document signature. This is based on mtime and size and used
+    // for the uptodate check (the value computed here is checked
+    // against the stored one). Changing the computation forces a full
+    // reindex of course.
+    sprintf(cbuf, "%ld%ld", (long)stp->st_size, (long)stp->st_mtime);
+    string sig = cbuf;
+    string udi;
+    make_udi(fn, "", udi);
+    if (!m_db.needUpdate(udi, sig)) {
 	LOGDEB(("processone: up to date: %s\n", fn.c_str()));
 	if (m_updater) {
+	    // Status bar update, abort request etc.
 	    m_updater->status.fn = fn;
 	    if (!m_updater->update()) {
 		return FsTreeWalker::FtwStop;
@@ -413,22 +427,23 @@ DbIndexer::processone(const std::string &fn, const struct stat *stp,
 		ercnt, charset.c_str(), path_getsimple(fn).c_str()));
     }
     LOGDEB2(("processone: fn transcoded from [%s] to [%s] (%s->%s)\n",
-	    path_getsimple(fn).c_str(), utf8fn.c_str(), charset.c_str(), "UTF-8"));
+	     path_getsimple(fn).c_str(), utf8fn.c_str(), charset.c_str(), 
+	     "UTF-8"));
+
+    string parent_udi;
+    make_udi(fn, "", parent_udi);
+    Rcl::Doc doc;
+    const string plus("+");
+    char ascdate[20];
+    sprintf(ascdate, "%ld", long(stp->st_mtime));
 
     FileInterner::Status fis = FileInterner::FIAgain;
     bool hadNullIpath = false;
-    Rcl::Doc doc;
-    const string plus = "+";
-    char ascdate[20];
-    sprintf(ascdate, "%ld", long(stp->st_mtime));
     while (fis == FileInterner::FIAgain) {
 	doc.erase();
 	string ipath;
 	fis = interner.internfile(doc, ipath);
 	if (fis == FileInterner::FIError) {
-	    list<string> ext = interner.getMissingExternal();
-	    m_missingExternal.merge(ext);
-	    m_missingExternal.unique();
 	    // We used to return at this point. 
 	    //
 	    // The nice side was that if a filter failed because of a
@@ -438,20 +453,17 @@ DbIndexer::processone(const std::string &fn, const struct stat *stp,
 	    // The not so nice point was that the file name was not
 	    // indexed.
 	    //
-	    // We now index at least the file name. We use a dirty
-	    // hack to ensure that the indexing will be retried each
-	    // time: the stored number as decimal ascii mtime is
-	    // prefixed with a '+', which doesnt change its value for
-	    // atoll() but is tested by rcldb::needUpdate()
-	    // Reset the date as set by the handler if any
+	    // We now index at least the file name and the mod time. 
+	    // We change the signature to ensure that the indexing will 
+	    // be retried every time. This can make indexing passes quite
+	    // slower if there are many files of types with no helper
 	    doc.fmtime.erase();
 	    // Go through:
 	} 
 
 	if (doc.fmtime.empty()) {
 	    // Set the date if this was not done in the document handler
-	    doc.fmtime = (fis == FileInterner::FIError) ? plus + ascdate :
-		ascdate;
+	    doc.fmtime = ascdate;
 	}
 
 	// Internal access path for multi-document files
@@ -460,13 +472,35 @@ DbIndexer::processone(const std::string &fn, const struct stat *stp,
 	else
 	    doc.ipath = ipath;
 
+	doc.url = string("file://") + fn;
+
 	// Note that the filter may have its own idea of the file name 
 	// (ie: mail attachment)
 	if (doc.utf8fn.empty())
 	    doc.utf8fn = utf8fn;
 
-	// Add document to database
-	if (!m_db.add(fn, doc, stp)) 
+	char cbuf[100]; 
+	sprintf(cbuf, "%ld", (long)stp->st_size);
+	doc.fbytes = cbuf;
+	// Document signature for up to date checks: concatenate mtime and 
+	// size. Note: looking for changes only, no need to parseback so no
+	// need for reversible formatting
+	sprintf(cbuf, "%ld%ld", (long)stp->st_size, (long)stp->st_mtime);
+	doc.sig = cbuf;
+	// If there was an error, ensure indexing will be
+	// retried. This is for the once missing, later installed
+	// filter case. It can make indexing much slower (if there are
+	// myriads of such files, the ext script is executed for them
+	// and fails every time)
+	if (fis == FileInterner::FIError) {
+	    doc.sig += plus;
+	}
+
+	// Add document to database. If there is an ipath, add it as a children
+	// of the file document.
+	string udi;
+	make_udi(fn, ipath, udi);
+	if (!m_db.addOrUpdate(udi, ipath.empty() ? "" : parent_udi, doc)) 
 	    return FsTreeWalker::FtwError;
 
 	// Tell what we are doing and check for interrupt request
@@ -491,7 +525,15 @@ DbIndexer::processone(const std::string &fn, const struct stat *stp,
 	fileDoc.fmtime = ascdate;
 	fileDoc.utf8fn = utf8fn;
 	fileDoc.mimetype = interner.getMimetype();
-	if (!m_db.add(fn, fileDoc, stp)) 
+	fileDoc.url = string("file://") + fn;
+
+	char cbuf[100]; 
+	sprintf(cbuf, "%ld", (long)stp->st_size);
+	fileDoc.fbytes = cbuf;
+	// Document signature for up to date checks.
+	sprintf(cbuf, "%ld%ld", (long)stp->st_size, (long)stp->st_mtime);
+	fileDoc.sig = cbuf;
+	if (!m_db.addOrUpdate(parent_udi, "", fileDoc)) 
 	    return FsTreeWalker::FtwError;
     }
 
