@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: internfile.cpp,v 1.38 2008/05/27 05:40:58 dockes Exp $ (C) 2004 J.F.Dockes";
+static char rcsid[] = "@(#$Id: internfile.cpp,v 1.46 2008/10/10 08:04:54 dockes Exp $ (C) 2004 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -42,12 +42,38 @@ using namespace std;
 #include "pathut.h"
 #include "wipedir.h"
 #include "rclconfig.h"
+#include "mh_html.h"
 
 // The internal path element separator. This can't be the same as the rcldb 
 // file to ipath separator : "|"
 static const string isep(":");
+static const string stxtplain("text/plain");
 
-// Execute the command to uncompress a file into a temporary one.
+set<string> FileInterner::o_missingExternal;
+map<string, set<string> >  FileInterner::o_typesForMissing;
+
+// This is used when the user wants to retrieve a search result doc's parent
+// (ie message having a given attachment)
+bool FileInterner::getEnclosing(const string &url, const string &ipath,
+				string &eurl, string &eipath)
+{
+    eurl = url;
+    eipath = ipath;
+    string::size_type colon;
+    LOGDEB(("FileInterner::getEnclosing(): [%s]\n", eipath.c_str()));
+    if (eipath.empty())
+	return false;
+    if ((colon =  eipath.find_last_of(isep)) != string::npos) {
+	eipath.erase(colon);
+    } else {
+	eipath.erase();
+    }
+    LOGDEB(("FileInterner::getEnclosing() after: [%s]\n", eipath.c_str()));
+    return true;
+}
+
+// Uncompress input file into a temporary one, by executing the appropriate
+// script.
 static bool uncompressfile(RclConfig *conf, const string& ifn, 
 			   const list<string>& cmdv, const string& tdir, 
 			   string& tfile)
@@ -76,7 +102,7 @@ static bool uncompressfile(RclConfig *conf, const string& ifn,
     ExecCmd ex;
     int status = ex.doexec(cmd, args, 0, &tfile);
     if (status || tfile.empty()) {
-	LOGERR(("uncompressfile: doexec: status 0x%x\n", status));
+	LOGERR(("uncompressfile: doexec: failed for [%s] status 0x%x\n", ifn.c_str(), status));
 	rmdir(tdir.c_str());
 	return false;
     }
@@ -85,6 +111,7 @@ static bool uncompressfile(RclConfig *conf, const string& ifn,
     return true;
 }
 
+// Delete temporary uncompressed file
 void FileInterner::tmpcleanup()
 {
     if (m_tdir.empty() || m_tfile.empty())
@@ -96,8 +123,12 @@ void FileInterner::tmpcleanup()
     }
 }
 
-// Handler==0 on return says we're in error, will be handled when calling
-// internfile
+// Constructor: identify the input file, possibly create an
+// uncompressed temporary copy, and create the top filter for the
+// uncompressed file type.
+//
+// Empty handler on return says that we're in error, this will be
+// processed by the first call to internfile().
 FileInterner::FileInterner(const std::string &f, const struct stat *stp,
 			   RclConfig *cnf, 
 			   const string& td, const string *imime)
@@ -150,7 +181,7 @@ FileInterner::FileInterner(const std::string &f, const struct stat *stp,
     if (!df) {
 	// No handler for this type, for now :( if indexallfilenames
 	// is set in the config, this normally wont happen (we get mh_unknown)
-	LOGDEB(("FileInterner:: no handler for %s\n", l_mime.c_str()));
+	LOGERR(("FileInterner:: ignored: [%s] mime [%s]\n", f.c_str(), l_mime.c_str()));
 	return;
     }
     df->set_property(Dijon::Filter::OPERATING_MODE, 
@@ -168,18 +199,22 @@ FileInterner::FileInterner(const std::string &f, const struct stat *stp,
     m_handlers.push_back(df);
     LOGDEB(("FileInterner::FileInterner: %s [%s]\n", l_mime.c_str(), 
 	     m_fn.c_str()));
-    m_targetMType = "text/plain";
+    m_targetMType = stxtplain;
 }
 
 FileInterner::~FileInterner()
 {
     tmpcleanup();
     for (vector<Dijon::Filter*>::iterator it = m_handlers.begin();
-	 it != m_handlers.end(); it++)
-	delete *it;
+	 it != m_handlers.end(); it++) {
+        returnMimeHandler(*it);
+    }
     // m_tempfiles will take care of itself
 }
 
+// Create a temporary file for a block of data (ie: attachment) found
+// while walking the internal document tree, with a type for which the
+// handler needs an actual file (ie : external script).
 bool FileInterner::dataToTempFile(const string& dt, const string& mt, 
 				  string& fn)
 {
@@ -213,35 +248,55 @@ bool FileInterner::dataToTempFile(const string& dt, const string& mt,
 
 // See if the error string is formatted as a missing helper message,
 // accumulate helper name if it is
-void FileInterner::maybeExternalMissing(const string& msg)
+void FileInterner::checkExternalMissing(const string& msg, const string& mt)
 {
     if (msg.find("RECFILTERROR") == 0) {
 	list<string> lerr;
 	stringToStrings(msg, lerr);
 	if (lerr.size() > 2) {
 	    list<string>::iterator it = lerr.begin();
-	    it++;
+	    lerr.erase(it++);
 	    if (*it == "HELPERNOTFOUND") {
-		it++;
-		m_missingExternal.push_back(it->c_str());
+		lerr.erase(it++);
+		string s;
+		stringsToString(lerr, s);
+		o_missingExternal.insert(s);
+		o_typesForMissing[s].insert(mt);
 	    }
 	}		    
     }
 }
 
-const list<string>& FileInterner::getMissingExternal() 
-{
-    m_missingExternal.sort();
-    m_missingExternal.unique();
-    return m_missingExternal;
-}
 void FileInterner::getMissingExternal(string& out) 
 {
-    m_missingExternal.sort();
-    m_missingExternal.unique();
-    stringsToString(m_missingExternal, out);
+    stringsToString(o_missingExternal, out);
 }
 
+void FileInterner::getMissingDescription(string& out)
+{
+    out.erase();
+
+    for (set<string>::const_iterator it = o_missingExternal.begin();
+	     it != o_missingExternal.end(); it++) {
+	out += *it;
+	map<string, set<string> >::const_iterator it2;
+	it2 = o_typesForMissing.find(*it);
+	if (it2 != o_typesForMissing.end()) {
+	    out += " (";
+	    set<string>::const_iterator it3;
+	    for (it3 = it2->second.begin(); 
+		 it3 != it2->second.end(); it3++) {
+		out += *it3;
+		out += string(" ");
+	    }
+	    trimstring(out);
+	    out += ")";
+	}	
+	out += "\n";
+    }
+}
+
+// Helper for extracting a value from a map.
 static inline bool getKeyValue(const map<string, string>& docdata, 
 			       const string& key, string& value)
 {
@@ -249,21 +304,23 @@ static inline bool getKeyValue(const map<string, string>& docdata,
     it = docdata.find(key);
     if (it != docdata.end()) {
 	value = it->second;
+	LOGDEB2(("getKeyValue: [%s]->[%s]\n", key.c_str(), value.c_str()));
 	return true;
     }
+    LOGDEB2(("getKeyValue: no value for [%s]\n", key.c_str()));
     return false;
 }
 
-static const string keyab("abstract");
+// These defs are for the Dijon meta array. Rcl::Doc predefined field
+// names are used where appropriate. In some cases, Rcl::Doc names are
+// used inside the Dijon metadata (ex: origcharset)
 static const string keyau("author");
 static const string keycs("charset");
 static const string keyct("content");
 static const string keyds("description");
 static const string keyfn("filename");
-static const string keykw("keywords");
 static const string keymd("modificationdate");
 static const string keymt("mimetype");
-static const string keyoc("origcharset");
 static const string keytt("title");
 
 bool FileInterner::dijontorcl(Rcl::Doc& doc)
@@ -277,22 +334,22 @@ bool FileInterner::dijontorcl(Rcl::Doc& doc)
 	    doc.text = it->second;
 	} else if (it->first == keymd) {
 	    doc.dmtime = it->second;
-	} else if (it->first == keyoc) {
+	} else if (it->first == Rcl::Doc::keyoc) {
 	    doc.origcharset = it->second;
 	} else if (it->first == keymt || it->first == keycs) {
-	    // don't need these.
+	    // don't need/want these.
 	} else {
 	    doc.meta[it->first] = it->second;
 	}
     }
-    if (doc.meta[keyab].empty() && !doc.meta[keyds].empty()) {
-	doc.meta[keyab] = doc.meta[keyds];
+    if (doc.meta[Rcl::Doc::keyabs].empty() && !doc.meta[keyds].empty()) {
+	doc.meta[Rcl::Doc::keyabs] = doc.meta[keyds];
 	doc.meta.erase(keyds);
     }
     return true;
 }
 
-// Collect the ipath stack. 
+// Collect the ipath from the current path in the document tree.
 // While we're at it, we also set the mimetype and filename, which are special 
 // properties: we want to get them from the topmost doc
 // with an ipath, not the last one which is usually text/plain
@@ -304,7 +361,6 @@ void FileInterner::collectIpathAndMT(Rcl::Doc& doc, string& ipath) const
 
     // If there is no ipath stack, the mimetype is the one from the file
     doc.mimetype = m_mimetype;
-    LOGDEB2(("INITIAL mimetype: %s\n", doc.mimetype.c_str()));
 
     string ipathel;
     for (vector<Dijon::Filter*>::const_iterator hit = m_handlers.begin();
@@ -321,7 +377,7 @@ void FileInterner::collectIpathAndMT(Rcl::Doc& doc, string& ipath) const
 	} else {
 	    ipath += isep;
 	}
-	getKeyValue(docdata, keyau, doc.meta["author"]);
+	getKeyValue(docdata, keyau, doc.meta[Rcl::Doc::keyau]);
 	getKeyValue(docdata, keymd, doc.dmtime);
     }
 
@@ -348,20 +404,113 @@ void FileInterner::popHandler()
 	m_tempfiles.pop_back();
 	m_tmpflgs[i] = false;
     }
-    delete m_handlers.back();
+    returnMimeHandler(m_handlers.back());
     m_handlers.pop_back();
 }
 
+enum addResols {ADD_OK, ADD_CONTINUE, ADD_BREAK, ADD_ERROR};
+
+// Just got document from current top handler. See what type it is,
+// and possibly add a filter/handler to the stack
+int FileInterner::addHandler()
+{
+    const std::map<std::string, std::string>& docdata = 
+	m_handlers.back()->get_meta_data();
+    string charset, mimetype;
+    getKeyValue(docdata, keycs, charset);
+    getKeyValue(docdata, keymt, mimetype);
+
+    LOGDEB(("FileInterner::addHandler: next_doc is %s\n", mimetype.c_str()));
+
+    // If we find a document of the target type (text/plain in
+    // general), we're done decoding. If we hit text/plain, we're done
+    // in any case
+    if (!stringicmp(mimetype, m_targetMType) || 
+	!stringicmp(mimetype, stxtplain)) {
+	m_reachedMType = mimetype;
+	LOGDEB1(("FileInterner::addHandler: target reached\n"));
+	return ADD_BREAK;
+    }
+
+    // We need to stack another handler. Check stack size
+    if (m_handlers.size() > MAXHANDLERS) {
+	// Stack too big. Skip this and go on to check if there is
+	// something else in the current back()
+	LOGERR(("FileInterner::addHandler: stack too high\n"));
+	return ADD_CONTINUE;
+    }
+
+    Dijon::Filter *newflt = getMimeHandler(mimetype, m_cfg);
+    if (!newflt) {
+	// If we can't find a handler, this doc can't be handled
+	// but there can be other ones so we go on
+	LOGINFO(("FileInterner::addHandler: no filter for [%s]\n",
+		 mimetype.c_str()));
+	return ADD_CONTINUE;
+    }
+    newflt->set_property(Dijon::Filter::OPERATING_MODE, 
+			m_forPreview ? "view" : "index");
+    newflt->set_property(Dijon::Filter::DEFAULT_CHARSET, charset);
+
+    // Get current content: we don't use getkeyvalue() here to avoid
+    // copying the text, which may be big.
+    string ns;
+    const string *txt = &ns;
+    {
+	map<string,string>::const_iterator it;
+	it = docdata.find(keyct);
+	if (it != docdata.end())
+	    txt = &it->second;
+    }
+    bool setres = false;
+    if (newflt->is_data_input_ok(Dijon::Filter::DOCUMENT_STRING)) {
+	setres = newflt->set_document_string(*txt);
+    } else if (newflt->is_data_input_ok(Dijon::Filter::DOCUMENT_DATA)) {
+	setres = newflt->set_document_data(txt->c_str(), txt->length());
+    } else if (newflt->is_data_input_ok(Dijon::Filter::DOCUMENT_FILE_NAME)) {
+	string filename;
+	if (dataToTempFile(*txt, mimetype, filename)) {
+	    if (!(setres = newflt->set_document_file(filename))) {
+		m_tmpflgs[m_handlers.size()-1] = false;
+		m_tempfiles.pop_back();
+	    }
+	}
+    }
+    if (!setres) {
+	LOGINFO(("FileInterner::addHandler: set_doc failed inside %s "
+		 " for mtype %s\n", m_fn.c_str(), mimetype.c_str()));
+	delete newflt;
+	if (m_forPreview)
+	    return ADD_ERROR;
+	return ADD_CONTINUE;
+    }
+    // add handler and go on, maybe this one will give us text...
+    m_handlers.push_back(newflt);
+    LOGDEB1(("FileInterner::addHandler: added\n"));
+    return ADD_OK;
+}
+
+// Information and debug after a next_document error
+void FileInterner::processNextDocError(Rcl::Doc &doc, string& ipath)
+{
+    collectIpathAndMT(doc, ipath);
+    m_reason = m_handlers.back()->get_error();
+    checkExternalMissing(m_reason, doc.mimetype);
+    LOGERR(("FileInterner::internfile: next_document error "
+	    "[%s%s%s] %s %s\n", m_fn.c_str(), ipath.empty() ? "" : "|", 
+	    ipath.c_str(), doc.mimetype.c_str(), m_reason.c_str()));
+}
+
 FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
 {
     LOGDEB(("FileInterner::internfile. ipath [%s]\n", ipath.c_str()));
     if (m_handlers.size() < 1) {
 	// Just means the constructor failed
-	LOGERR(("FileInterner::internfile: constructor failed\n"));
+	LOGDEB(("FileInterner::internfile: no handler: constructor failed\n"));
 	return FIError;
     }
 
-    // Ipath vector.
+    // Input Ipath vector when retrieving a given subdoc for previewing
     // Note that the vector is big enough for the maximum stack. All values
     // over the last significant one are ""
     // We set the ipath for the first handler here, others are set
@@ -378,118 +527,67 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
 	}
     }
 
-    /* Try to get doc from the topmost filter */
-    // Security counter: we try not to loop but ...
+    // Try to get doc from the topmost handler
+    // Security counter: looping happens when we stack one other 
+    // handler or when walking the file document tree without finding
+    // something to index (typical exemple: email with multiple image
+    // attachments and no image filter installed). So we need to be
+    // quite generous here, especially because there is another
+    // security in the form of a maximum handler stack size.
     int loop = 0;
     while (!m_handlers.empty()) {
-	if (loop++ > 30) {
+	if (loop++ > 1000) {
 	    LOGERR(("FileInterner:: looping!\n"));
 	    return FIError;
 	}
+	// If there are no more docs at the current top level we pop and
+	// see if there is something at the previous one
 	if (!m_handlers.back()->has_documents()) {
-	    // No docs at the current top level. Pop and see if there
-	    // is something at the previous one
 	    popHandler();
 	    continue;
 	}
 
-	// Don't stop on next_document() error. There might be ie an
-	// error while decoding an attachment, but we still want to
-	// process the rest of the mbox!
+	// While indexing, don't stop on next_document() error. There
+	// might be ie an error while decoding an attachment, but we
+	// still want to process the rest of the mbox! For preview: fatal.
 	if (!m_handlers.back()->next_document()) {
-	    Rcl::Doc doc; string ipath;
-	    collectIpathAndMT(doc, ipath);
-	    m_reason = m_handlers.back()->get_error();
-	    maybeExternalMissing(m_reason);
-	    LOGERR(("FileInterner::internfile: next_document error [%s%s%s] %s\n",
-		    m_fn.c_str(), ipath.empty()?"":"|", ipath.c_str(), 
-		    m_reason.c_str()));
-	    // If fetching a specific document, this is fatal
-	    if (m_forPreview) {
+	    processNextDocError(doc, ipath);
+	    if (m_forPreview) 
 		return FIError;
-	    }
 	    popHandler();
 	    continue;
 	}
 
-	// Look at what we've got
-	const std::map<std::string, std::string>& docdata = 
-	    m_handlers.back()->get_meta_data();
-	string charset, mimetype;
-	getKeyValue(docdata, keycs, charset);
-	getKeyValue(docdata, keymt, mimetype);
-
-	LOGDEB(("FileInterner::internfile: next_doc is %s\n",
-		mimetype.c_str()));
-	// If we find a text/plain doc, we're done
-	if (!stringicmp(mimetype, m_targetMType))
-	    break;
-
-	// Got a non text/plain doc. We need to stack another
-	// filter. Check current size
-	if (m_handlers.size() > MAXHANDLERS) {
-	    // Stack too big. Skip this and go on to check if there is
-	    // something else in the current back()
-	    LOGINFO(("FileInterner::internfile: stack too high\n"));
+	// Look at the type for the next document and possibly add
+	// handler to stack.
+	switch (addHandler()) {
+	case ADD_OK: // Just go through: handler has been stacked, use it
+	    break; 
+	case ADD_CONTINUE: 
+	    // forget this doc and retrieve next from current handler
+	    // (ipath stays same)
 	    continue;
+	case ADD_BREAK: 
+	    // Stop looping: doc type ok, need complete its processing
+	    // and return it
+	    goto breakloop; // when you have to you have to
+	case ADD_ERROR: return FIError;
 	}
 
-	Dijon::Filter *again = getMimeHandler(mimetype, m_cfg);
-	if (!again) {
-	    // If we can't find a filter, this doc can't be handled
-	    // but there can be other ones so we go on
-	    LOGINFO(("FileInterner::internfile: no filter for [%s]\n",
-		    mimetype.c_str()));
-	    continue;
-	}
-	again->set_property(Dijon::Filter::OPERATING_MODE, 
-			    m_forPreview ? "view" : "index");
-	again->set_property(Dijon::Filter::DEFAULT_CHARSET, 
-			    charset);
-	string ns;
-	const string *txt = &ns;
-	map<string,string>::const_iterator it;
-	it = docdata.find("content");
-	if (it != docdata.end())
-	    txt = &it->second;
-
-	bool setres = false;
-	if (again->is_data_input_ok(Dijon::Filter::DOCUMENT_STRING)) {
-	    setres = again->set_document_string(*txt);
-	} else if (again->is_data_input_ok(Dijon::Filter::DOCUMENT_DATA)) {
-	    setres = again->set_document_data(txt->c_str(), txt->length());
-	}else if(again->is_data_input_ok(Dijon::Filter::DOCUMENT_FILE_NAME)) {
-	    string filename;
-	    if (dataToTempFile(*txt, mimetype, filename)) {
-		if (!(setres = again->set_document_file(filename))) {
-		    m_tmpflgs[m_handlers.size()-1] = false;
-		    m_tempfiles.pop_back();
-		}
-	    }
-	}
-	if (!setres) {
-	    LOGINFO(("FileInterner::internfile: set_doc failed inside %s\n", 
-		    m_fn.c_str()));
-	    delete again;
-	    if (m_forPreview)
-		return FIError;
-	    continue;
-	}
-	// add filter and go on, maybe this one will give us text...
-	m_handlers.push_back(again);
 	if (!ipath.empty() &&
 	    !m_handlers.back()->skip_to_document(vipath[m_handlers.size()-1])){
 	    LOGERR(("FileInterner::internfile: can't skip\n"));
 	    return FIError;
 	}
     }
+ breakloop:
 
     if (m_handlers.empty()) {
-	LOGERR(("FileInterner::internfile: conversion ended with no doc\n"));
+	LOGDEB(("FileInterner::internfile: conversion ended with no doc\n"));
 	return FIError;
     }
 
-    // If indexing compute ipath and significant mimetype Note that
+    // If indexing compute ipath and significant mimetype.
     // ipath is returned through the parameter not doc.ipath We also
     // retrieve some metadata fields from the ancesters (like date or
     // author). This is useful for email attachments. The values will
@@ -497,11 +595,22 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
     // of calls is important.
     if (!m_forPreview)
 	collectIpathAndMT(doc, ipath);
+    else
+	doc.mimetype = m_reachedMType;
+
     // Keep this AFTER collectIpathAndMT
     dijontorcl(doc);
 
-    // Destack what can be
+    // Possibly destack so that we can test for FIDone. While doing this
+    // possibly set aside an ancestor html text (for the GUI preview)
     while (!m_handlers.empty() && !m_handlers.back()->has_documents()) {
+	if (m_forPreview) {
+	    MimeHandlerHtml *hth = 
+		dynamic_cast<MimeHandlerHtml*>(m_handlers.back());
+	    if (hth) {
+		m_html = hth->get_html();
+	    }
+	}
 	popHandler();
     }
     if (m_handlers.empty())
@@ -610,6 +719,11 @@ Usage(void)
 static int        op_flags;
 #define OPT_q	  0x1 
 
+RclConfig *config;
+RclConfig *RclConfig::getMainConfig()
+{
+    return config;
+}
 int main(int argc, char **argv)
 {
     thisprog = argv[0];
@@ -639,7 +753,7 @@ int main(int argc, char **argv)
 	argc--;
     }
     string reason;
-    RclConfig *config = recollinit(0, 0, reason);
+    config = recollinit(0, 0, reason);
 
     if (config == 0 || !config->ok()) {
 	string str = "Configuration problem: ";
