@@ -16,7 +16,7 @@
  */
 #ifndef _MH_EXEC_H_INCLUDED_
 #define _MH_EXEC_H_INCLUDED_
-/* @(#$Id: mh_exec.h,v 1.4 2007/10/25 15:50:31 dockes Exp $  (C) 2004 J.F.Dockes */
+/* @(#$Id: mh_exec.h,v 1.8 2008/10/06 06:22:46 dockes Exp $  (C) 2004 J.F.Dockes */
 
 #include <string>
 #include <list>
@@ -26,13 +26,28 @@ using std::string;
 #include "mimehandler.h"
 
 /** 
-    Turn external document into internal one by executing an external filter.
-    The command to execute, and its parameters, come from the mimeconf file
-*/
+ * Turn external document into internal one by executing an external filter.
+ *
+ * The command to execute, and its parameters, are stored in the "params" 
+ * which is built in mimehandler.cpp out of data from the mimeconf file.
+ */
 class MimeHandlerExec : public RecollFilter {
  public:
+    // Members not reset by clear().  params, cfgMtype and chgCharset
+    // actually define what I am.  missingHelper is a permanent error
+    // (no use to try and execute over and over something that's not
+    // here).
     list<string> params;
-    MimeHandlerExec(const string& mt) : RecollFilter(mt) {}
+    // The defaults for external filters is to output html except if defined 
+    // otherwise in the config.
+    string cfgMtype;
+    // For ext programs which don't output html, the output charset
+    // has to be known: ie they have a --charset utf-8 like option.
+    string cfgCharset; 
+    bool missingHelper;
+
+    MimeHandlerExec(const string& mt) : RecollFilter(mt), missingHelper(false) 
+    {}
     virtual ~MimeHandlerExec() {}
     virtual bool set_document_file(const string &file_path) {
 	m_fn = file_path;
@@ -40,8 +55,19 @@ class MimeHandlerExec : public RecollFilter {
 	return true;
     }
     virtual bool next_document();
+    virtual bool skip_to_document(const string& ipath) {
+	m_ipath = ipath;
+	return true;
+    }
+    virtual void clear() {
+	m_fn.erase(); 
+	m_ipath.erase();
+	RecollFilter::clear(); 
+    }
+
 private:
     string m_fn;
+    string m_ipath;
 };
 
 #endif /* _MH_EXEC_H_INCLUDED_ */
