@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: guiutils.cpp,v 1.36 2008/05/05 20:24:55 dockes Exp $ (C) 2005 Jean-Francois Dockes";
+static char rcsid[] = "@(#$Id: guiutils.cpp,v 1.39 2008/10/03 08:09:35 dockes Exp $ (C) 2005 Jean-Francois Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -111,18 +111,6 @@ bool startHelpBrowser(const string &iurl)
     return false;
 }
 
-// Printable url: either utf-8 if transcoding succeeds, or url-encoded
-bool printableUrl(const string &in, string &out)
-{
-    string fcharset = rclconfig->getDefCharset(true);
-    int ecnt = 0;
-    if (!transcode(in, out, fcharset, "UTF-8", &ecnt) || ecnt) {
-	out = url_encode(in, 7);
-    }
-    return true;
-}
-
-
 // The global preferences structure
 PrefsPack prefs;
 
@@ -159,6 +147,8 @@ void rwSettings(bool writing)
 	       "/Recoll/prefs/startWithAdvSearchOpen", Bool, false);
     SETTING_RW(prefs.startWithSortToolOpen, 
 	       "/Recoll/prefs/startWithSortToolOpen", Bool, false);
+    SETTING_RW(prefs.previewHtml, 
+	       "/Recoll/prefs/previewHtml", Bool, true);
 
     QString advSearchClauses;
     QString ascdflt;
@@ -219,7 +209,7 @@ void rwSettings(bool writing)
     SETTING_RW(prefs.syntAbsCtx, "/Recoll/prefs/query/syntAbsCtx", 
 	       Num, 4);
 
-    SETTING_RW(prefs.sortWidth, "/Recoll/prefs/query/sortWidth", 
+    SETTING_RW(prefs.sortDepth, "/Recoll/prefs/query/sortDepth",
 	       Num, 100);
     SETTING_RW(prefs.sortSpec, "/Recoll/prefs/query/sortSpec", 
 	       Num, 0);
