@@ -17,7 +17,7 @@
 #ifndef _GUIUTILS_H_INCLUDED_
 #define _GUIUTILS_H_INCLUDED_
 /* 
- * @(#$Id: guiutils.h,v 1.26 2008/05/05 20:24:55 dockes Exp $  (C) 2005 Jean-Francois Dockes 
+ * @(#$Id: guiutils.h,v 1.29 2008/10/03 08:09:35 dockes Exp $  (C) 2005 Jean-Francois Dockes 
  *                         jean-francois.dockes@wanadoo.fr
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -55,8 +55,6 @@ bool getStemLangs(list<string>& langs);
 /** Start a browser on the help document */
 extern bool startHelpBrowser(const string& url = "");
 
-/** Try to make an utf8 printable url */
-extern bool printableUrl(const string &in, string &out);
 
 /** Holder for preferences (gets saved to user Qt prefs) */
 class PrefsPack {
@@ -83,6 +81,7 @@ class PrefsPack {
     bool queryReplaceAbstract;
     bool startWithAdvSearchOpen;
     bool startWithSortToolOpen;
+    bool previewHtml;
     // Extra query indexes. This are encoded to base64 before storing
     // to the qt settings file to avoid any bin string/ charset conv issues
     list<string> allExtraDbs;
@@ -103,7 +102,7 @@ class PrefsPack {
     int syntAbsCtx;
 
     // Sort specs (sort_w.cpp knows how to deal with the values
-    int sortWidth;
+    int sortDepth;
     int sortSpec;
 
     // Remembered term match mode
