@@ -4,7 +4,7 @@
     <name>AdvSearch</name>
     <message>
         <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
-        <translation type="obsolete">Impossible d&apos;exécuter une requête purement négative. Essayez d&apos;entrer des termes courants dans un champ &apos;ou&apos;</translation>
+        <translation>Ausschließlich negative Suche nicht möglich. Bitte geben Sie mindestens einen positiven Suchbegriff an.</translation>
     </message>
     <message>
         <source>All clauses</source>
@@ -14,10 +14,6 @@
         <source>Any clause</source>
         <translation>Einen der Ausdrücke</translation>
     </message>
-    <message>
-        <source>Cannot execute pure negativequery. Please enter common terms in the &apos;any words&apos; field</source>
-        <translation>Ausschließlich negative Suche nicht möglich. Bitte geben Sie mindestens einen positiven Suchbegriff an.</translation>
-    </message>
     <message>
         <source>texts</source>
         <translation>Texte</translation>
@@ -235,7 +231,7 @@ Drücken Sie Abbrechen, um die Konfigurationsdatei vor dem Start der Indizierung
     </message>
     <message>
         <source>Match &amp;Case</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Groß/Kleinschreibung &amp;beachten</translation>
     </message>
     <message>
         <source>Alt+C</source>
@@ -442,7 +438,7 @@ Drücken Sie Abbrechen, um die Konfigurationsdatei vor dem Start der Indizierung
     </message>
     <message>
         <source>Query results (sorted)</source>
-        <translation>Ergebnisse (sortiert)</translation>
+        <translation type="obsolete">Ergebnisse (sortiert)</translation>
     </message>
     <message>
         <source>Document history</source>
@@ -497,7 +493,7 @@ Drücken Sie Abbrechen, um die Konfigurationsdatei vor dem Start der Indizierung
         <translation>Diese Suche ist nicht mehr aktiv</translation>
     </message>
     <message>
-        <source>Cant start query: </source>
+        <source>Can&apos;t start query: </source>
         <translation>Kann die Suche nicht starten:</translation>
     </message>
     <message>
@@ -532,6 +528,68 @@ Soll der Voreinstellungsdialog geöffnet werden?</translation>
         <source>error retrieving stemming languages</source>
         <translation>Fehler beim Holen der Wortstammsprachen</translation>
     </message>
+    <message>
+        <source>Update &amp;Index</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Indexing interrupted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop &amp;Indexing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>media</source>
+        <translation type="unfinished">Medien</translation>
+    </message>
+    <message>
+        <source>message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>other</source>
+        <translation type="unfinished">andere</translation>
+    </message>
+    <message>
+        <source>presentation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>spreadsheet</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sorted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>filtered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>External applications/commands needed and not found for indexing your file types:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No helpers found missing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Missing helper programs</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -723,6 +781,14 @@ Soll der Voreinstellungsdialog geöffnet werden?</translation>
         <source>&amp;Indexing configuration</source>
         <translation>&amp;Indizierungskonfiguration</translation>
     </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Show missing helpers</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RclResList</name>
@@ -757,7 +823,7 @@ Soll der Voreinstellungsdialog geöffnet werden?</translation>
         <translation type="obsolete">&amp;Copier le nom de fichier</translation>
     </message>
     <message>
-        <source>Copy &amp;Url</source>
+        <source>Copy &amp;URL</source>
         <translation type="obsolete">Copier l&apos;&amp;Url</translation>
     </message>
     <message>
@@ -818,7 +884,7 @@ Soll der Voreinstellungsdialog geöffnet werden?</translation>
         <translation type="obsolete">&amp;Copier le nom de fichier</translation>
     </message>
     <message>
-        <source>Copy &amp;Url</source>
+        <source>Copy &amp;URL</source>
         <translation>&amp;Url kopieren</translation>
     </message>
     <message>
@@ -853,6 +919,18 @@ Soll der Voreinstellungsdialog geöffnet werden?</translation>
         <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; for </source>
         <translation>Dokumente &lt;b&gt;%1-%2&lt;/b&gt; für </translation>
     </message>
+    <message>
+        <source>filtered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sorted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Document history</source>
+        <translation type="unfinished">Dokumenthistorie</translation>
+    </message>
 </context>
 <context>
     <name>ResListBase</name>
@@ -1567,7 +1645,7 @@ Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalte
         <translation>Alle Auswählen</translation>
     </message>
     <message>
-        <source>Desactivate All</source>
+        <source>Deactivate All</source>
         <translation>Alle Abwählen</translation>
     </message>
     <message>
@@ -1594,6 +1672,14 @@ Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalte
         <source>Texts over this size will not be highlighted in preview (too slow).</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Highlight color for query terms</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prefer Html to plain text for preview.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewAction</name>
@@ -1771,8 +1857,8 @@ Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalte
         <translation>Ausgelassene Pfade</translation>
     </message>
     <message>
-        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/tmp*&apos;, not &apos;/usr/home/tmp*&apos;)</source>
-        <translation>Die Namen der Verzeichnisse, die nicht indiziert werden.&lt;br&gt;Kann Wildcards enthalten. Muss den Pfaden entsprechen, die der Indexer sieht (z.B. wenn &apos;/home/me&apos; in den topdirs steht und &apos;/home&apos; eigentlich ein link zu &apos;/usr/home&apos; ist, dann wäre ein korrekter skippedPath Eintrag &apos;/home/tmp*&apos; und nicht &apos;/usr/home/tmp*&apos;)</translation>
+        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
+        <translation>Die Namen der Verzeichnisse, die nicht indiziert werden.&lt;br&gt;Kann Wildcards enthalten. Muss den Pfaden entsprechen, die der Indexer sieht (z.B. wenn &apos;/home/me&apos; in den topdirs steht und &apos;/home&apos; eigentlich ein link zu &apos;/usr/home&apos; ist, dann wäre ein korrekter skippedPath Eintrag &apos;/home/me/tmp*&apos; und nicht &apos;/usr/home/me/tmp*&apos;)</translation>
     </message>
     <message>
         <source>Stemming languages</source>
@@ -1803,7 +1889,7 @@ Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalte
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>This value adjust the amount of data which is indexed betweeen flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
+        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1818,10 +1904,6 @@ Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalte
         <source>No aspell usage</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful is aspell is absent or does not work. </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Aspell language</source>
         <translation type="unfinished"></translation>
@@ -1846,5 +1928,9 @@ Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalte
         <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
         <translation>Benutze das &apos;file&apos; Kommando wenn die interne&lt;br&gt;mime Typ Erkennung fehlschlägt.</translation>
     </message>
+    <message>
+        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
