@@ -3,7 +3,7 @@
     <name>AdvSearch</name>
     <message>
         <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
-        <translation type="obsolete">Impossible d&apos;exécuter une requête purement négative. Essayez d&apos;entrer des termes courants dans un champ &apos;ou&apos;</translation>
+        <translation>Requête négative pure impossible. Entrer un terme dans un des autres champs</translation>
     </message>
     <message>
         <source>All clauses</source>
@@ -13,10 +13,6 @@
         <source>Any clause</source>
         <translation>Une des clauses</translation>
     </message>
-    <message>
-        <source>Cannot execute pure negativequery. Please enter common terms in the &apos;any words&apos; field</source>
-        <translation>Requête négative pure impossible. Entrer un terme dans un des autres champs</translation>
-    </message>
     <message>
         <source>texts</source>
         <translation>textes</translation>
@@ -440,7 +436,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>Query results (sorted)</source>
-        <translation>Résultats de la recherche (triés)</translation>
+        <translation type="obsolete">Résultats de la recherche (triés)</translation>
     </message>
     <message>
         <source>Document history</source>
@@ -464,7 +460,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>Starting help browser </source>
-        <translation>Demarrage de l&apos;outil de consultation de l&apos;aide</translation>
+        <translation>Démarrage de l&apos;outil de consultation de l&apos;aide</translation>
     </message>
     <message>
         <source>Indexing in progress: </source>
@@ -495,7 +491,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
         <translation>Cette recherche n&apos;est plus active</translation>
     </message>
     <message>
-        <source>Cant start query: </source>
+        <source>Can&apos;t start query: </source>
         <translation>Impossible de démarrer la recherche:</translation>
     </message>
     <message>
@@ -530,6 +526,70 @@ Voulez vous ouvrir le dialogue de paramétrage ?</translation>
         <source>error retrieving stemming languages</source>
         <translation>impossible de trouver la liste des langages d&apos;expansion</translation>
     </message>
+    <message>
+        <source>Update &amp;Index</source>
+        <translation>Mise à jour &amp;Index</translation>
+    </message>
+    <message>
+        <source>Indexing interrupted</source>
+        <translation>Indexation interrompue</translation>
+    </message>
+    <message>
+        <source>Stop &amp;Indexing</source>
+        <translation>Arrèter l&apos;&amp;Indexation</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Tout</translation>
+    </message>
+    <message>
+        <source>media</source>
+        <translation>multimédia</translation>
+    </message>
+    <message>
+        <source>message</source>
+        <translation>message</translation>
+    </message>
+    <message>
+        <source>other</source>
+        <translation>autres</translation>
+    </message>
+    <message>
+        <source>presentation</source>
+        <translation>présentation</translation>
+    </message>
+    <message>
+        <source>spreadsheet</source>
+        <translation>feuille de calcul</translation>
+    </message>
+    <message>
+        <source>text</source>
+        <translation>texte</translation>
+    </message>
+    <message>
+        <source>sorted</source>
+        <translation>trié</translation>
+    </message>
+    <message>
+        <source>filtered</source>
+        <translation>filtré</translation>
+    </message>
+    <message>
+        <source>External applications/commands needed and not found for indexing your file types:
+
+</source>
+        <translation>Applications externes non trouvees pour indexer vos types de fichiers:
+
+</translation>
+    </message>
+    <message>
+        <source>No helpers found missing</source>
+        <translation>Pas d&apos;applications manquantes</translation>
+    </message>
+    <message>
+        <source>Missing helper programs</source>
+        <translation>Applications manquantes</translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -547,7 +607,7 @@ Voulez vous ouvrir le dialogue de paramétrage ?</translation>
     </message>
     <message>
         <source>Previous page</source>
-        <translation>Page précedente</translation>
+        <translation>Page précédente</translation>
     </message>
     <message>
         <source>Next page</source>
@@ -607,7 +667,7 @@ Voulez vous ouvrir le dialogue de paramétrage ?</translation>
     </message>
     <message>
         <source>&amp;Preferences</source>
-        <translation>&amp;Preferences</translation>
+        <translation>&amp;Préférences</translation>
     </message>
     <message>
         <source>Search tools</source>
@@ -721,6 +781,14 @@ Voulez vous ouvrir le dialogue de paramétrage ?</translation>
         <source>&amp;Indexing configuration</source>
         <translation>Configuration &amp;Indexation</translation>
     </message>
+    <message>
+        <source>All</source>
+        <translation>Tout</translation>
+    </message>
+    <message>
+        <source>&amp;Show missing helpers</source>
+        <translation>Afficher les application&amp;s manquantes</translation>
+    </message>
 </context>
 <context>
     <name>RclResList</name>
@@ -755,7 +823,7 @@ Voulez vous ouvrir le dialogue de paramétrage ?</translation>
         <translation type="obsolete">&amp;Copier le nom de fichier</translation>
     </message>
     <message>
-        <source>Copy &amp;Url</source>
+        <source>Copy &amp;URL</source>
         <translation type="obsolete">Copier l&apos;&amp;Url</translation>
     </message>
     <message>
@@ -793,7 +861,7 @@ Voulez vous ouvrir le dialogue de paramétrage ?</translation>
     </message>
     <message>
         <source>Previous</source>
-        <translation></translation>
+        <translation>Précédent</translation>
     </message>
     <message>
         <source>Next</source>
@@ -816,7 +884,7 @@ Voulez vous ouvrir le dialogue de paramétrage ?</translation>
         <translation type="obsolete">&amp;Copier le nom de fichier</translation>
     </message>
     <message>
-        <source>Copy &amp;Url</source>
+        <source>Copy &amp;URL</source>
         <translation>Copier l&apos;&amp;Url</translation>
     </message>
     <message>
@@ -851,6 +919,18 @@ Voulez vous ouvrir le dialogue de paramétrage ?</translation>
         <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; for </source>
         <translation>Résultats &lt;b&gt;%1-%2&lt;/b&gt; pour </translation>
     </message>
+    <message>
+        <source>filtered</source>
+        <translation>filtré</translation>
+    </message>
+    <message>
+        <source>sorted</source>
+        <translation>trié</translation>
+    </message>
+    <message>
+        <source>Document history</source>
+        <translation>Historique des documents consultés</translation>
+    </message>
 </context>
 <context>
     <name>ResListBase</name>
@@ -1554,7 +1634,7 @@ Ceci devrait donner une meilleure pertinence aux résultats où les termes reche
         <translation>Tout activer</translation>
     </message>
     <message>
-        <source>Desactivate All</source>
+        <source>Deactivate All</source>
         <translation>Tout désactiver</translation>
     </message>
     <message>
@@ -1589,6 +1669,14 @@ Ceci devrait donner une meilleure pertinence aux résultats où les termes reche
         <source>Texts over this size will not be highlighted in preview (too slow).</source>
         <translation>Les texte plus gros ne seront pas surlignes dans la previsualisation (trop lent).</translation>
     </message>
+    <message>
+        <source>Highlight color for query terms</source>
+        <translation>Couleur de mise en relief des termes recherchés</translation>
+    </message>
+    <message>
+        <source>Prefer Html to plain text for preview.</source>
+        <translation>Utiliser le format Html pour la previsualisation.</translation>
+    </message>
 </context>
 <context>
     <name>ViewAction</name>
@@ -1766,7 +1854,7 @@ Ceci devrait donner une meilleure pertinence aux résultats où les termes reche
         <translation>Chemins ignores</translation>
     </message>
     <message>
-        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/tmp*&apos;, not &apos;/usr/home/tmp*&apos;)</source>
+        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
         <translation>Ce sont des noms de repertoires ou l&apos;indexation n&apos;entrera pas.&lt;br&gt;Ils peuvent contenir des caracteres jokers. Les chemins doivent correspondre a ceux vus par l&apos;indexeur (par exemple: si un des repertoires de depart est &apos;/home/me&apos; et que &apos;/home&apos; est un lien sur &apos;/usr/home&apos;, une entree correcte ici serait &apos;/home/me/tmp*&apos; , pas &apos;/usr/home/me/tmp*&apos;)</translation>
     </message>
     <message>
@@ -1798,7 +1886,7 @@ Ceci devrait donner une meilleure pertinence aux résultats où les termes reche
         <translation>Intervalle d&apos;ecriture de l&apos;index en megaoctets</translation>
     </message>
     <message>
-        <source>This value adjust the amount of data which is indexed betweeen flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
+        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
         <translation>Ajuste la quantite de donnees lues entre les ecritures sur disque.&lt;br&gt;Controle l&apos;utilisation de la memoire. Defaut 10 Mo </translation>
     </message>
     <message>
@@ -1815,7 +1903,7 @@ Ceci devrait donner une meilleure pertinence aux résultats où les termes reche
     </message>
     <message>
         <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful is aspell is absent or does not work. </source>
-        <translation>Interdit l&apos;utilisation d&apos;aspell pour generer un dictionnaire d&apos;approximation phonetique (outil d&apos;exploration des termes)&lt;br&gt;
+        <translation type="obsolete">Interdit l&apos;utilisation d&apos;aspell pour generer un dictionnaire d&apos;approximation phonetique (outil d&apos;exploration des termes)&lt;br&gt;
 Utile si aspell est absent ou ne fonctionne pas bien.</translation>
     </message>
     <message>
@@ -1842,5 +1930,9 @@ Utile si aspell est absent ou ne fonctionne pas bien.</translation>
         <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
         <translation>Utiliser la commande &apos;file&apos; si la determination&lt;br&gt;interne du type mime n&apos;obtient pas de resultat.</translation>
     </message>
+    <message>
+        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
+        <translation>Désactiver l&apos;utilisation d&apos;aspell pour générer les approximations orthographiques.&lt;br&gt; Utile si aspell n&apos;est pas installé ou ne fonctionne pas. </translation>
+    </message>
 </context>
 </TS>
