@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: main.cpp,v 1.66 2008/02/19 08:02:20 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: main.cpp,v 1.70 2008/09/30 12:38:29 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -100,9 +100,6 @@ bool maybeOpenDb(string &reason, bool force)
 	return false;
     }
 
-    int qopts = Rcl::Db::QO_NONE;
-    if (prefs.queryStemLang.length() > 0)
-	qopts |= Rcl::Db::QO_STEM;
     if (force)
 	rcldb->close();
     rcldb->rmQueryDb("");
@@ -112,7 +109,7 @@ bool maybeOpenDb(string &reason, bool force)
 	rcldb->addQueryDb(*it);
     }
     if (!rcldb->isopen() && !rcldb->open(dbdir, rclconfig->getStopfile(),
-					 Rcl::Db::DbRO, qopts)) {
+					 Rcl::Db::DbRO)) {
 	reason = "Could not open database in " + 
 	    dbdir + " wait for indexing to complete?";
 	return false;
@@ -208,7 +205,7 @@ int main(int argc, char **argv)
 
     //    fprintf(stderr, "Application created\n");
     string a_config;
-    string qstring;
+    string question;
 
     thisprog = argv[0];
     argc--; argv++;
@@ -228,7 +225,7 @@ int main(int argc, char **argv)
 	    case 'l': op_flags |= OPT_l; break;
 	    case 'o': op_flags |= OPT_o; break;
 	    case 'q':	op_flags |= OPT_q; if (argc < 2)  Usage();
-		qstring = *(++argv);
+		question = *(++argv);
 		argc--; goto b1;
 	    case 't': op_flags |= OPT_t; break;
 	    }
@@ -341,12 +338,11 @@ int main(int argc, char **argv)
 		 "Ok", "Cancel", 0,   0)) {
 
 	case 0: // Ok: indexing is going to start.
-	    startindexing = 1;
+	    start_indexing(true);
 	    break;
 
 	case 1: // Cancel
 	    needindexconfig = true;
-	    startindexing = 0;
 	    break;
 	}
     }
@@ -386,7 +382,7 @@ int main(int argc, char **argv)
 	}
 	mainWindow->sSearch->searchTypCMB->setCurrentItem(int(stype));
 	mainWindow->
-	    sSearch->setSearchString(QString::fromUtf8(qstring.c_str()));
+	    sSearch->setSearchString(QString::fromLocal8Bit(question.c_str()));
 	// The 200 ms are a hack to jump over the first db close by 
 	// periodic100()... 
 	QTimer::singleShot(200, mainWindow->sSearch, SLOT(startSimpleSearch()));
