@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: preview_w.cpp,v 1.34 2008/05/21 07:21:37 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: preview_w.cpp,v 1.39 2008/10/07 16:19:15 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -345,17 +345,17 @@ void Preview::doSearch(const QString &_text, bool next, bool reverse,
 	    return;
 	if (reverse) {
 	    if (m_curAnchor == 1)
-		m_curAnchor = m_lastAnchor;
+		m_curAnchor = m_plaintorich.lastanchor;
 	    else
 		m_curAnchor--;
 	} else {
-	    if (m_curAnchor == m_lastAnchor)
+	    if (m_curAnchor == m_plaintorich.lastanchor)
 		m_curAnchor = 1;
 	    else
 		m_curAnchor++;
 	}
 	QString aname = 
-	    QString::fromUtf8(termAnchorName(m_curAnchor).c_str());
+	   QString::fromUtf8(m_plaintorich.termAnchorName(m_curAnchor).c_str());
 	edit->moveToAnchor(aname);
 	return;
     }
@@ -552,7 +552,7 @@ void Preview::setCurTabProps(const string &fn, const Rcl::Doc &doc,
     }
     LOGDEB(("Doc.url: [%s]\n", doc.url.c_str()));
     string url;
-    printableUrl(doc.url, url);
+    printableUrl(rclconfig->getDefCharset(), doc.url, url);
     string tiptxt = url + string("\n");
     tiptxt += doc.mimetype + " " + string(datebuf) + "\n";
     if (meta_it != doc.meta.end() && !meta_it->second.empty())
@@ -670,8 +670,12 @@ class LoadThread : public QThread {
 	    *statusp = -1;
 	    return;
 	}
-	    
+	
 	FileInterner interner(filename, &st, rclconfig, tmpdir, mtype);
+	// We don't set the interner's target mtype to html because we
+	// do want the html filter to do its work: we won't use the
+	// text, but we need the conversion to utf-8
+	// interner.setTargetMType("text/html");
 	try {
 	    FileInterner::Status ret = interner.internfile(*out, ipath);
 	    if (ret == FileInterner::FIDone || ret == FileInterner::FIAgain) {
@@ -682,6 +686,10 @@ class LoadThread : public QThread {
 		// a mysterious error. Happens when the file name matches a
 		// a search term of course.
 		*statusp = 0;
+		if (prefs.previewHtml && !interner.get_html().empty()) {
+		    out->text = interner.get_html();
+		    out->mimetype = "text/html";
+		}
 	    } else {
 		out->mimetype = interner.getMimetype();
 		interner.getMissingExternal(missing);
@@ -699,11 +707,11 @@ class ToRichThread : public QThread {
     const HiliteData &hdata;
     list<string> &out;
     int loglevel;
-    int *lastanchor;
+    PlainToRichQtPreview& ptr;
  public:
     ToRichThread(string &i, const HiliteData& hd, list<string> &o, 
-		 int *lsta)
-	: in(i), hdata(hd), out(o), lastanchor(lsta)
+		 PlainToRichQtPreview& _ptr)
+	: in(i), hdata(hd), out(o), ptr(_ptr)
     {
 	    loglevel = DebugLog::getdbl()->getlevel();
     }
@@ -711,7 +719,7 @@ class ToRichThread : public QThread {
     {
 	DebugLog::getdbl()->setloglevel(loglevel);
 	try {
-	    plaintorich(in, out, hdata, false, lastanchor);
+	    ptr.plaintorich(in, out, hdata);
 	} catch (CancelExcept) {
 	}
     }
@@ -753,8 +761,8 @@ bool Preview::loadFileInCurrentTab(string fn, size_t sz, const Rcl::Doc &idoc,
 
     Rcl::Doc doc = idoc;
 
-    if (doc.meta["title"].empty()) 
-	doc.meta["title"] = path_getsimple(doc.url);
+    if (doc.meta[Rcl::Doc::keytt].empty()) 
+	doc.meta[Rcl::Doc::keytt] = path_getsimple(doc.url);
 
     setCurTabProps(fn, doc, docnum);
 
@@ -820,15 +828,22 @@ bool Preview::loadFileInCurrentTab(string fn, size_t sz, const Rcl::Doc &idoc,
     // somehow slipped through previous processing.
     bool highlightTerms = fdoc.text.length() < 
 	(unsigned long)prefs.maxhltextmbs * 1024 * 1024;
+
     // Final text is produced in chunks so that we can display the top
     // while still inserting at bottom
     list<QString> qrichlst;
-
+    bool inputishtml = !fdoc.mimetype.compare("text/html");
     if (highlightTerms) {
 	progress.setLabelText(tr("Creating preview text"));
 	qApp->processEvents();
+	if (inputishtml) {
+	    LOGDEB1(("Preview: got html %s\n", fdoc.text.c_str()));
+	    m_plaintorich.set_inputhtml(true);
+	} else {
+	    m_plaintorich.set_inputhtml(false);
+	}
 	list<string> richlst;
-	ToRichThread rthr(fdoc.text, m_hData, richlst, &m_lastAnchor);
+	ToRichThread rthr(fdoc.text, m_hData, richlst, m_plaintorich);
 	rthr.start();
 
 	for (;;prog++) {
@@ -855,23 +870,29 @@ bool Preview::loadFileInCurrentTab(string fn, size_t sz, const Rcl::Doc &idoc,
 		richlst.back() += "<b>Cancelled !</b>";
 	    }
 	}
-	// Convert to QString list
+	// Convert C++ string list to QString list
 	for (list<string>::iterator it = richlst.begin(); 
 	     it != richlst.end(); it++) {
 	    qrichlst.push_back(QString::fromUtf8(it->c_str(), it->length()));
 	}
     } else {
-	// No plaintorich() call.
-	// In this case, the text will no be identified as
-	// richtxt/html (no <html> or <qt> etc. at the beginning), and
-	// there is no need to escape special characters.
-	// Also we need to split in chunks (so that the top is displayed faster),
-	// and we must do it on a QString (to avoid utf8 issues).
+	LOGDEB(("Preview: no hilighting\n"));
+	// No plaintorich() call.  In this case, either the text is
+	// html and the html quoting is hopefully correct, or it's
+	// plain-text and there is no need to escape special
+	// characters. We'd still want to split in chunks (so that the
+	// top is displayed faster), but we must not cut tags, and
+	// it's too difficult on html. For text we do the splitting on
+	// a QString to avoid utf8 issues.
 	QString qr = QString::fromUtf8(fdoc.text.c_str(), fdoc.text.length());
 	int l = 0;
-	for (int pos = 0; pos < (int)qr.length(); pos += l) {
-	    l = MIN(CHUNKL, qr.length() - pos);
-	    qrichlst.push_back(qr.mid(pos, l));
+	if (inputishtml) {
+	    qrichlst.push_back(qr);
+	} else {
+	    for (int pos = 0; pos < (int)qr.length(); pos += l) {
+		l = MIN(CHUNKL, qr.length() - pos);
+		qrichlst.push_back(qr.mid(pos, l));
+	    }
 	}
     }
 	    
@@ -911,7 +932,7 @@ bool Preview::loadFileInCurrentTab(string fn, size_t sz, const Rcl::Doc &idoc,
 
     progress.close();
 
-    m_haveAnchors = m_lastAnchor != 0;
+    m_haveAnchors = m_plaintorich.lastanchor != 0;
     if (searchTextLine->text().length() != 0) {
 	// If there is a current search string, perform the search
 	m_canBeep = true;
@@ -919,7 +940,8 @@ bool Preview::loadFileInCurrentTab(string fn, size_t sz, const Rcl::Doc &idoc,
     } else {
 	// Position to the first query term
 	if (m_haveAnchors) {
-	    QString aname = QString::fromUtf8(termAnchorName(1).c_str());
+	    QString aname = 
+		QString::fromUtf8(m_plaintorich.termAnchorName(1).c_str());
 	    LOGDEB2(("Call movetoanchor(%s)\n", (const char *)aname.utf8()));
 	    editor->moveToAnchor(aname);
 	    m_curAnchor = 1;
