@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: rclmain_w.cpp,v 1.48 2008/02/19 08:02:01 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: rclmain_w.cpp,v 1.57 2008/10/13 07:57:12 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -36,6 +36,8 @@ using std::pair;
 #if (QT_VERSION < 0x040000)
 #include <qcstring.h>
 #include <qpopupmenu.h>
+#include <qradiobutton.h>
+#include <qbuttongroup.h>
 #endif
 #include <qtabwidget.h>
 #include <qtimer.h>
@@ -95,6 +97,13 @@ static QIconSet createIconSet(const QString &name)
 
 void RclMain::init()
 {
+    // This is just to get the common catg strings into the message file
+    static const char* catg_strings[] = {
+            QT_TR_NOOP("All"), QT_TR_NOOP("media"),  QT_TR_NOOP("message"),
+            QT_TR_NOOP("other"),  QT_TR_NOOP("presentation"),
+            QT_TR_NOOP("spreadsheet"),  QT_TR_NOOP("text"), 
+	    QT_TR_NOOP("sorted"), QT_TR_NOOP("filtered")
+    };
 
     curPreview = 0;
     asearchform = 0;
@@ -102,7 +111,6 @@ void RclMain::init()
     uiprefs = 0;
     indexConfig = 0;
     spellform = 0;
-    m_searchId = 0;
     m_idxStatusAck = false;
 
     // Set the focus to the search terms entry:
@@ -147,6 +155,22 @@ void RclMain::init()
     }
     preferencesMenu->setItemChecked(curid, true);
 
+    // Document categories buttons
+    catgBGRP->setColumnLayout(1, Qt::Vertical);
+    list<string> cats;
+    rclconfig->getMimeCategories(cats);
+    // Text for button 0 is not used. Next statement just avoids unused
+    // variable compiler warning for catg_strings
+    m_catgbutvec.push_back(catg_strings[0]);
+    for (list<string>::const_iterator it = cats.begin();
+	 it != cats.end(); it++) {
+	QRadioButton *but = new QRadioButton(catgBGRP);
+	QString catgnm = QString::fromUtf8(it->c_str(), it->length());
+	m_catgbutvec.push_back(*it);
+	but->setText(tr(catgnm));
+    }
+    catgBGRP->setButton(0);
+
     // Connections
     connect(sSearch, SIGNAL(startSearch(RefCntr<Rcl::SearchData>)), 
 		this, SLOT(startSearch(RefCntr<Rcl::SearchData>)));
@@ -155,8 +179,7 @@ void RclMain::init()
     connect(preferencesMenu, SIGNAL(aboutToShow()),
 	    this, SLOT(adjustPrefsMenu()));
     // signals and slots connections
-    connect(sSearch, SIGNAL(clearSearch()),
-	    this, SLOT(resetSearch()));
+    connect(sSearch, SIGNAL(clearSearch()), this, SLOT(resetSearch()));
     connect(firstPageAction, SIGNAL(activated()), 
 	    resList, SLOT(resultPageFirst()));
     connect(prevPageAction, SIGNAL(activated()), 
@@ -188,6 +211,8 @@ void RclMain::init()
 	    this, SLOT(eraseDocHistory()));
     connect(helpAbout_RecollAction, SIGNAL(activated()), 
 	    this, SLOT(showAboutDialog()));
+    connect(showMissingHelpers_Action, SIGNAL(activated()), 
+	    this, SLOT(showMissingHelpers()));
     connect(userManualAction, SIGNAL(activated()), this, SLOT(startManual()));
     connect(toolsDoc_HistoryAction, SIGNAL(activated()), 
 	    this, SLOT(showDocHistory()));
@@ -205,7 +230,7 @@ void RclMain::init()
     connect(indexConfigAction, SIGNAL(activated()), this, SLOT(showIndexConfig()));
     connect(queryPrefsAction, SIGNAL(activated()), this, SLOT(showUIPrefs()));
     connect(extIdxAction, SIGNAL(activated()), this, SLOT(showExtIdxDialog()));
-
+    connect(catgBGRP, SIGNAL(clicked(int)), this, SLOT(catgFilter(int)));
 
 #if (QT_VERSION < 0x040000)
     nextPageAction->setIconSet(createIconSet("nextpage.png"));
@@ -231,7 +256,7 @@ void RclMain::init()
     if (prefs.keepSort && prefs.sortActive) {
 	SortForm sf(0);
 	connect(&sf, SIGNAL(sortDataChanged(DocSeqSortSpec)), 
-		this, SLOT(sortDataChanged(DocSeqSortSpec)));
+		resList, SLOT(setSortParams(DocSeqSortSpec)));
 	// Have to call setdata again after sig connected...
 	sf.setData();
     }
@@ -337,20 +362,20 @@ void RclMain::periodic100()
 {
     static int toggle = 0;
     // Check if indexing thread done
-    if (indexingstatus != IDXTS_NULL) {
+    if (idxthread_getStatus() != IDXTS_NULL) {
 	// Indexing is stopped
 	statusBar()->message("");
 	fileToggleIndexingAction->setText(tr("Update &Index"));
 	fileToggleIndexingAction->setEnabled(TRUE);
 	if (m_idxStatusAck == false) {
 	    m_idxStatusAck = true;
-	    if (indexingstatus != IDXTS_OK) {
+	    if (idxthread_getStatus() != IDXTS_OK) {
 		if (idxthread_idxInterrupted()) {
 		    QMessageBox::warning(0, "Recoll", 
 					 tr("Indexing interrupted"));
 		} else {
 		    QMessageBox::warning(0, "Recoll", 
-					 QString::fromAscii(indexingReason.c_str()));
+		       QString::fromAscii(idxthread_getReason().c_str()));
 		}
 	    }
 	    // Make sure we reopen the db to get the results. If there
@@ -406,12 +431,12 @@ void RclMain::periodic100()
 
 void RclMain::toggleIndexing()
 {
-    if (indexingstatus == IDXTS_NULL) {
+    if (idxthread_getStatus() == IDXTS_NULL) {
 	// Indexing in progress
-	stopindexing = 1;
+	stop_indexing();
 	fileToggleIndexingAction->setText(tr("Update &Index"));
     } else {
-	startindexing = 1;
+	start_indexing(false);
 	fileToggleIndexingAction->setText(tr("Stop &Indexing"));
     }
     fileToggleIndexingAction->setEnabled(FALSE);
@@ -427,64 +452,43 @@ static string urltolocalpath(string url)
 void RclMain::startSearch(RefCntr<Rcl::SearchData> sdata)
 {
     LOGDEB(("RclMain::startSearch. Indexing %s\n", 
-	    indexingstatus == IDXTS_NULL?"on":"off"));
+	    idxthread_getStatus() == IDXTS_NULL?"on":"off"));
     // The db may have been closed at the end of indexing
     string reason;
     // If indexing is being performed, we reopen the db at each query.
-    if (!maybeOpenDb(reason, indexingstatus == IDXTS_NULL)) {
+    if (!maybeOpenDb(reason, idxthread_getStatus() == IDXTS_NULL)) {
 	QMessageBox::critical(0, "Recoll", QString(reason.c_str()));
 	return;
     }
 
-    resList->resetSearch();
-
-    int qopts = 0;
-    if (!prefs.queryStemLang.length() == 0)
-	qopts |= Rcl::Db::QO_STEM;
+    resList->resetList();
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     string stemLang = (const char *)prefs.queryStemLang.ascii();
     if (stemLang == "ALL") {
 	rclconfig->getConfParam("indexstemminglanguages", stemLang);
     }
+    sdata->setStemlang(stemLang);
 
-    if (!rcldb->setQuery(sdata, qopts, stemLang)) {
-	QMessageBox::warning(0, "Recoll", tr("Cant start query: ") +
-			     QString::fromAscii(rcldb->getReason().c_str()));
+    Rcl::Query *query = new Rcl::Query(rcldb);
+
+    if (!query || !query->setQuery(sdata)) {
+	QMessageBox::warning(0, "Recoll", tr("Can't start query: ") +
+			     QString::fromAscii(query->getReason().c_str()));
 	QApplication::restoreOverrideCursor();
 	return;
     }
     curPreview = 0;
     DocSequenceDb *src = 
-	new DocSequenceDb(rcldb, string(tr("Query results").utf8()), sdata);
-    m_docSource = RefCntr<DocSequence>(src);
-    m_searchData = sdata;
-    setDocSequence();
+	new DocSequenceDb(RefCntr<Rcl::Query>(query), 
+			  string(tr("Query results").utf8()), sdata);
+    resList->setDocSource(RefCntr<DocSequence>(src));
     QApplication::restoreOverrideCursor();
 }
 
 void RclMain::resetSearch()
 {
-    resList->resetSearch();
-    m_searchData = RefCntr<Rcl::SearchData>();
-}
-
-void RclMain::setDocSequence()
-{
-    if (m_searchData.getcnt() == 0) {
-	// Null refcntr ?? No current search data 
-	return;
-    }
-    RefCntr<DocSequence> docsource;
-    if (m_sortspecs.sortwidth > 0) {
-	docsource = RefCntr<DocSequence>(new DocSeqSorted(m_docSource, 
-							  m_sortspecs,
-			  string(tr("Query results (sorted)").utf8())));
-    } else {
-	docsource = m_docSource;
-    }
-    m_searchId++;
-    resList->setDocSource(docsource);
+    resList->resetList();
 }
 
 // Open advanced search dialog.
@@ -507,16 +511,15 @@ void RclMain::showSortDialog()
     if (sortform == 0) {
 	sortform = new SortForm(0);
 	connect(sortform, SIGNAL(sortDataChanged(DocSeqSortSpec)), 
-		this, SLOT(sortDataChanged(DocSeqSortSpec)));
+		resList, SLOT(setSortParams(DocSeqSortSpec)));
 	connect(sortform, SIGNAL(applySortData()), 
-		this, SLOT(setDocSequence()));
+		resList, SLOT(setDocSource()));
 	sortform->show();
     } else {
 	// Close and reopen, in hope that makes us visible...
 	sortform->close();
         sortform->show();
     }
-
 }
 
 void RclMain::showSpellDialog()
@@ -574,6 +577,25 @@ void RclMain::showExtIdxDialog()
     uiprefs->show();
 }
 
+void RclMain::showAboutDialog()
+{
+    string vstring = string("Recoll ") + rclversion + 
+	"<br>" + "http://www.recoll.org";
+    QMessageBox::information(this, tr("About Recoll"), vstring.c_str());
+}
+void RclMain::showMissingHelpers()
+{
+    string miss = rclconfig->getMissingHelperDesc();
+    QString msg = tr("External applications/commands needed and not found "
+		     "for indexing your file types:\n\n");
+    if (!miss.empty()) {
+	msg += QString::fromUtf8(miss.c_str());
+    } else {
+	msg += tr("No helpers found missing");
+    }
+    QMessageBox::information(this, tr("Missing helper programs"), msg);
+}
+
 // If a preview (toplevel) window gets closed by the user, we need to
 // clean up because there is no way to reopen it. And check the case
 // where the current one is closed
@@ -600,9 +622,8 @@ void RclMain::startPreview(int docnum, int mod)
 {
     Rcl::Doc doc;
     if (!resList->getDoc(docnum, doc)) {
-	QMessageBox::warning(0, "Recoll",
-			     tr("Cannot retrieve document info" 
-				     " from database"));
+	QMessageBox::warning(0, "Recoll", tr("Cannot retrieve document info" 
+					     " from database"));
 	return;
     }
 	
@@ -620,8 +641,8 @@ void RclMain::startPreview(int docnum, int mod)
     }
     if (curPreview == 0) {
 	HiliteData hdata;
-	m_searchData->getTerms(hdata.terms, hdata.groups, hdata.gslks);
-	curPreview = new Preview(m_searchId, hdata);
+	resList->getTerms(hdata.terms, hdata.groups, hdata.gslks);
+	curPreview = new Preview(resList->listId(), hdata);
 	if (curPreview == 0) {
 	    QMessageBox::warning(0, tr("Warning"), 
 				 tr("Can't create preview window"),
@@ -691,13 +712,13 @@ void RclMain::previewPrevInTab(Preview * w, int sid, int docnum)
 // Combined next/prev from result list in current preview tab
 void RclMain::previewPrevOrNextInTab(Preview * w, int sid, int docnum, bool nxt)
 {
-    LOGDEB(("RclMain::previewNextInTab  sid %d docnum %d, m_sid %d\n", 
-	    sid, docnum, m_searchId));
+    LOGDEB(("RclMain::previewNextInTab  sid %d docnum %d, listId %d\n", 
+	    sid, docnum, resList->listId()));
 
     if (w == 0) // ??
 	return;
 
-    if (sid != m_searchId) {
+    if (sid != resList->listId()) {
 	QMessageBox::warning(0, "Recoll", 
 			     tr("This search is not active any more"));
 	return;
@@ -731,13 +752,13 @@ void RclMain::previewPrevOrNextInTab(Preview * w, int sid, int docnum, bool nxt)
     w->makeDocCurrent(fn, st.st_size, doc, docnum, true);
 }
 
-// Preview tab exposed: possibly tell reslist (to color the paragraph)
+// Preview tab exposed: if the preview comes from the currently
+// displayed result list, tell reslist (to color the paragraph)
 void RclMain::previewExposed(Preview *, int sid, int docnum)
 {
     LOGDEB2(("RclMain::previewExposed: sid %d docnum %d, m_sid %d\n", 
-	     sid, docnum, m_searchId));
-
-    if (sid != m_searchId) {
+	     sid, docnum, resList->listId()));
+    if (sid != resList->listId()) {
 	return;
     }
     resList->previewExposed(docnum);
@@ -848,16 +869,16 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
     // configured command seems to be able to grok it or not.
     bool wantsipath = cmd.find("%i") != string::npos;
     bool istempfile = false;
-    string fn, url;
+    string fn = urltolocalpath(doc.url);
+    string url;
+    rclconfig->setKeyDir(path_getfather(fn));
     if (doc.ipath.empty() || wantsipath) {
-	fn = urltolocalpath(doc.url);
 	url = url_encode(doc.url, 7);
     } else {
 	// There is an ipath and the command does not know about
 	// them. We need a temp file.
 	TempFile temp;
-	if (!FileInterner::idocTempFile(temp, rclconfig, 
-					urltolocalpath(doc.url), 
+	if (!FileInterner::idocTempFile(temp, rclconfig, fn, 
 					doc.ipath, doc.mimetype)) {
 	    QMessageBox::warning(0, "Recoll",
 				 tr("Cannot extract document or create "
@@ -895,14 +916,6 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
     system(ncmd.c_str());
 }
 
-
-void RclMain::showAboutDialog()
-{
-    string vstring = string("Recoll ") + rclversion + 
-	"<br>" + "http://www.recoll.org";
-    QMessageBox::information(this, tr("About Recoll"), vstring.c_str());
-}
-
 void RclMain::startManual()
 {
     QString msg = tr("Starting help browser ");
@@ -912,7 +925,8 @@ void RclMain::startManual()
     startHelpBrowser();
 }
 
-// Search for document 'like' the selected one.
+// Search for document 'like' the selected one. We ask rcldb/xapian to find
+// significant terms, and add them to the simple search entry.
 void RclMain::docExpand(int docnum)
 {
     if (!rcldb)
@@ -921,7 +935,7 @@ void RclMain::docExpand(int docnum)
     if (!resList->getDoc(docnum, doc))
 	return;
     list<string> terms;
-    terms = rcldb->expand(doc);
+    terms = resList->expand(doc);
     if (terms.empty())
 	return;
     // Do we keep the original query. I think we'd better not.
@@ -941,7 +955,7 @@ void RclMain::docExpand(int docnum)
 void RclMain::showDocHistory()
 {
     LOGDEB(("RclMain::showDocHistory\n"));
-    resList->resetSearch();
+    resList->resetList();
     curPreview = 0;
 
     string reason;
@@ -950,36 +964,27 @@ void RclMain::showDocHistory()
 	return;
     }
     // Construct a bogus SearchData structure
-    m_searchData = 
+    RefCntr<Rcl::SearchData>searchdata = 
 	RefCntr<Rcl::SearchData>(new Rcl::SearchData(Rcl::SCLT_AND));
-    m_searchData->setDescription((const char *)tr("History data").utf8());
+    searchdata->setDescription((const char *)tr("History data").utf8());
 
-    m_searchId++;
 
     // If you change the title, also change it in eraseDocHistory()
     DocSequenceHistory *src = 
 	new DocSequenceHistory(rcldb, g_dynconf, 
 			       string(tr("Document history").utf8()));
     src->setDescription((const char *)tr("History data").utf8());
-    m_docSource = RefCntr<DocSequence>(src);
-    setDocSequence();
+    resList->setDocSource(RefCntr<DocSequence>(src));
 }
 
+// Erase all memory of documents viewed
 void RclMain::eraseDocHistory()
 {
+    // Clear file storage
     g_dynconf->eraseAll(RclHistory::docSubkey);
-    // We want to reset the displayed history if it is currently shown. Using
-    // the title value is an ugly hack
-    if (m_docSource->title() == 
-	string((const char *)tr("Document history").utf8())) {
+    // Clear possibly displayed history
+    if (resList->displayingHistory())
 	showDocHistory();
-    }
-}
-
-void RclMain::sortDataChanged(DocSeqSortSpec spec)
-{
-    LOGDEB(("RclMain::sortDataChanged\n"));
-    m_sortspecs = spec;
 }
 
 // Called when the uiprefs dialog is ok'd
@@ -1007,3 +1012,24 @@ void RclMain::enablePrevPage(bool yesno)
     firstPageAction->setEnabled(yesno);
 }
 
+// User pressed a category button: set filter params in reslist
+void RclMain::catgFilter(int id)
+{
+    LOGDEB(("RclMain::catgFilter: id %d\n"));
+    if (id < 0 || id >= int(m_catgbutvec.size()))
+	return; 
+
+    DocSeqFiltSpec spec;
+
+    if (id != 0)  {
+	string catg = m_catgbutvec[id];
+	list<string> tps;
+	rclconfig->getMimeCatTypes(catg, tps);
+	for (list<string>::const_iterator it = tps.begin();
+	     it != tps.end(); it++) 
+	    spec.orCrit(DocSeqFiltSpec::DSFS_MIMETYPE, *it);
+    }
+
+    resList->setFilterParams(spec);
+    resList->setDocSource();
+}
