@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: reslist.cpp,v 1.39 2008/05/21 07:21:37 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: reslist.cpp,v 1.47 2008/09/29 11:33:55 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 
 #include <time.h>
@@ -41,6 +41,7 @@ static char rcsid[] = "@(#$Id: reslist.cpp,v 1.39 2008/05/21 07:21:37 dockes Exp
 #include "mimehandler.h"
 #include "plaintorich.h"
 #include "refcntr.h"
+#include "internfile.h"
 
 #include "reslist.h"
 #include "moc_reslist.cpp"
@@ -49,6 +50,14 @@ static char rcsid[] = "@(#$Id: reslist.cpp,v 1.39 2008/05/21 07:21:37 dockes Exp
 #define MIN(A,B) ((A) < (B) ? (A) : (B))
 #endif
 
+
+class PlainToRichQtReslist : public PlainToRich {
+public:
+    virtual ~PlainToRichQtReslist() {}
+    virtual string startMatch() {return string("<termtag>");}
+    virtual string endMatch() {return string("</termtag>");}
+};
+
 ResList::ResList(QWidget* parent, const char* name)
     : QTEXTBROWSER(parent, name)
 {
@@ -72,15 +81,73 @@ ResList::ResList(QWidget* parent, const char* name)
     m_winfirst = -1;
     m_curPvDoc = -1;
     m_lstClckMod = 0;
+    m_listId = 0;
 }
 
 ResList::~ResList()
 {
 }
 
+int ResList::newListId()
+{
+    static int id;
+    return ++id;
+}
+
 extern "C" int XFlush(void *);
 
-void ResList::resetSearch() 
+void ResList::setDocSource(RefCntr<DocSequence> ndocsource)
+{
+    m_baseDocSource = ndocsource;
+    setDocSource();
+}
+
+// Reapply parameters. Sort params probably changed
+void ResList::setDocSource()
+{
+    if (m_baseDocSource.isNull())
+	return;
+    resetList();
+    m_listId = newListId();
+    m_docSource = m_baseDocSource;
+
+    // Filtering must be done before sorting, (which usually
+    // truncates the original list)
+    if (m_baseDocSource->canFilter()) {
+	m_baseDocSource->setFiltSpec(m_filtspecs);
+    } else {
+	if (m_filtspecs.isNotNull()) {
+	    string title = m_baseDocSource->title() + " (" + 
+		string((const char*)tr("filtered").utf8()) + ")";
+	    m_docSource = 
+		RefCntr<DocSequence>(new DocSeqFiltered(m_docSource,m_filtspecs,
+							title));
+	} 
+    }
+
+    if (m_sortspecs.isNotNull()) {
+	string title = m_baseDocSource->title() + " (" + 
+	    string((const char *)tr("sorted").utf8()) + ")";
+	m_docSource = RefCntr<DocSequence>(new DocSeqSorted(m_docSource, 
+							    m_sortspecs,
+							    title));
+    }
+    resultPageNext();
+}
+
+void ResList::setSortParams(const DocSeqSortSpec& spec)
+{
+    LOGDEB(("ResList::setSortParams\n"));
+    m_sortspecs = spec;
+}
+
+void ResList::setFilterParams(const DocSeqFiltSpec& spec)
+{
+    LOGDEB(("ResList::setFilterParams\n"));
+    m_filtspecs = spec;
+}
+
+void ResList::resetList() 
 {
     m_winfirst = -1;
     m_curPvDoc = -1;
@@ -101,17 +168,31 @@ void ResList::resetSearch()
 #endif
 }
 
+bool ResList::displayingHistory()
+{
+    // We want to reset the displayed history if it is currently
+    // shown. Using the title value is an ugly hack
+    string htstring = string((const char *)tr("Document history").utf8());
+    return m_docSource->title().find(htstring) == 0;
+}
+
 void ResList::languageChange()
 {
     setCaption(tr("Result list"));
 }
 
-// Acquire new docsource
-void ResList::setDocSource(RefCntr<DocSequence> docsource)
+bool ResList::getTerms(vector<string>& terms, 
+		       vector<vector<string> >& groups, vector<int>& gslks)
 {
-    resetSearch();
-    m_docSource = docsource;
-    resultPageNext();
+    // We could just
+    return m_baseDocSource->getTerms(terms, groups, gslks);
+}
+
+list<string> ResList::expand(Rcl::Doc& doc)
+{
+    if (m_baseDocSource.isNull())
+	return list<string>();
+    return m_baseDocSource->expand(doc);
 }
 
 // Get document number from paragraph number
@@ -205,7 +286,7 @@ void ResList::contentsMouseReleaseEvent(QMouseEvent *e)
 // Return total result list count
 int ResList::getResCnt()
 {
-    if (m_docSource.getcnt() == 0)
+    if (m_docSource.isNull())
 	return -1;
     return m_docSource->getResCnt();
 }
@@ -287,8 +368,7 @@ void ResList::append(const QString &text)
 // Fill up result list window with next screen of hits
 void ResList::resultPageNext()
 {
-    // This checks that the RefCntr pseudo-pointer is not holding a null.
-    if (m_docSource.getcnt() == 0)
+    if (m_docSource.isNull())
 	return;
 
     int resCnt = m_docSource->getResCnt();
@@ -402,15 +482,19 @@ void ResList::resultPageNext()
     //      setUpdatesEnabled(false);
     for (int i = 0; i < pagelen; i++) {
 
-	int &percent(respage[i].percent);
 	Rcl::Doc &doc(respage[i].doc);
 	string& sh(respage[i].subHeader);
-
-	if (percent == -1) {
+	int percent;
+	if (doc.pc == -1) {
 	    percent = 0;
 	    // Document not available, maybe other further, will go on.
-	    doc.meta["abstract"] = string(tr("Unavailable document").utf8());
+	    doc.meta[Rcl::Doc::keyabs] = string(tr("Unavailable document").utf8());
+	} else {
+	    percent = doc.pc;
 	}
+	// Percentage of 'relevance'
+	char perbuf[10];
+	sprintf(perbuf, "%3d%% ", percent);
 
 	// Determine icon to display if any
 	string img_name;
@@ -424,17 +508,13 @@ void ResList::resultPageNext()
 		setImage(img_name.c_str(), image);
 	}
 
-	// Percentage of 'relevance'
-	char perbuf[10];
-	sprintf(perbuf, "%3d%% ", percent);
-
 	// Printable url: either utf-8 if transcoding succeeds, or url-encoded
 	string url;
-	printableUrl(doc.url, url);
+	printableUrl(rclconfig->getDefCharset(), doc.url, url);
 
 	// Make title out of file name if none yet
-	if (doc.meta["title"].empty()) {
-	    doc.meta["title"] = path_getsimple(url);
+	if (doc.meta[Rcl::Doc::keytt].empty()) {
+	    doc.meta[Rcl::Doc::keytt] = path_getsimple(url);
 	}
 
 	// Result number
@@ -476,11 +556,12 @@ void ResList::resultPageNext()
 	    (doc.syntabs || prefs.queryReplaceAbstract)) {
 	    abstract = m_docSource->getAbstract(doc);
 	} else {
-	    abstract = doc.meta["abstract"];
+	    abstract = doc.meta[Rcl::Doc::keyabs];
 	}
 	// No need to call escapeHtml(), plaintorich handles it
 	list<string> lr;
-	plaintorich(abstract, lr, hdata, true, 0, 100000);
+	PlainToRichQtReslist ptr;
+	ptr.plaintorich(abstract, lr, hdata);
 	string richabst = lr.front();
 
 	// Links;
@@ -510,14 +591,14 @@ void ResList::resultPageNext()
 	subs['A'] = !richabst.empty() ? richabst + "<br>" : "";
 	subs['D'] = datebuf;
 	subs['I'] = img_name;
-	subs['K'] = !doc.meta["keywords"].empty() ? 
-	    escapeHtml(doc.meta["keywords"]) + "<br>" : "";
+	subs['K'] = !doc.meta[Rcl::Doc::keykw].empty() ? 
+	    escapeHtml(doc.meta[Rcl::Doc::keykw]) + "<br>" : "";
 	subs['L'] = linksbuf;
 	subs['N'] = numbuf;
 	subs['M'] = doc.mimetype;
 	subs['R'] = perbuf;
 	subs['S'] = sizebuf;
-	subs['T'] = escapeHtml(doc.meta["title"]);
+	subs['T'] = escapeHtml(doc.meta[Rcl::Doc::keytt]);
 	subs['U'] = url;
 
 	string formatted;
@@ -653,7 +734,7 @@ RCLPOPUP *ResList::createPopupMenu(const QPoint& pos)
     popup->insertItem(tr("&Preview"), this, SLOT(menuPreview()));
     popup->insertItem(tr("&Edit"), this, SLOT(menuEdit()));
     popup->insertItem(tr("Copy &File Name"), this, SLOT(menuCopyFN()));
-    popup->insertItem(tr("Copy &Url"), this, SLOT(menuCopyURL()));
+    popup->insertItem(tr("Copy &URL"), this, SLOT(menuCopyURL()));
     popup->insertItem(tr("Find &similar documents"), this, SLOT(menuExpand()));
     popup->insertItem(tr("P&arent document/folder"), 
 		      this, SLOT(menuSeeParent()));
@@ -670,29 +751,15 @@ void ResList::menuSeeParent()
     Rcl::Doc doc;
     if (getDoc(m_popDoc, doc)) {
 	Rcl::Doc doc1;
-	if (doc.ipath.empty()) {
+	if (FileInterner::getEnclosing(doc.url, doc.ipath, 
+				       doc1.url, doc1.ipath)) {
+	    emit previewRequested(doc1);
+	} else {
 	    // No parent doc: show enclosing folder with app configured for
 	    // directories
 	    doc1.url = path_getfather(doc.url);
 	    doc1.mimetype = "application/x-fsdirectory";
 	    emit editRequested(doc1);
-	} else {
-	    doc1.url = doc.url;
-	    doc1.ipath = doc.ipath;
-	    string::size_type colon;
-	    LOGDEB(("Ipath: [%s]\n", doc1.ipath.c_str()));
-	    if ((colon=doc1.ipath.find_last_of(":")) != string::npos) {
-		doc1.ipath.erase(colon);
-	    } else {
-		doc1.ipath.erase();
-	    }
-	    LOGDEB(("Ipath after: [%s]\n", doc1.ipath.c_str()));
-
-	    list<string> lipath;
-	    stringToTokens(doc.ipath, lipath, ":");
-	    if (lipath.size() >= 1)
-		lipath.pop_back();
-	    emit previewRequested(doc1);
 	}
     }
 }
