@@ -1,6 +1,6 @@
 #ifndef _RESLIST_H_INCLUDED_
 #define _RESLIST_H_INCLUDED_
-/* @(#$Id: reslist.h,v 1.13 2007/08/02 06:33:35 dockes Exp $  (C) 2005 J.F.Dockes */
+/* @(#$Id: reslist.h,v 1.16 2008/09/29 07:13:47 dockes Exp $  (C) 2005 J.F.Dockes */
 
 #include <list>
 
@@ -21,8 +21,20 @@ class Q3PopupMenu;
 #endif
 
 #include "docseq.h"
+#include "sortseq.h"
+#include "filtseq.h"
 #include "refcntr.h"
+#include "rcldoc.h"
 
+/**
+ * Display a list of document records. The data can be out of the history 
+ * manager or from an index query, both abstracted as a DocSequence. 
+ * Sorting and filtering are applied by stacking Sort/Filter DocSequences.
+ * This is nice because history and index result are handled the same, but 
+ * not nice because we can't use the sort/filter capabilities in the index 
+ * engine, and do it instead on the index output, which duplicates code and 
+ * may be sometimes slower.
+ */
 class ResList : public QTEXTBROWSER
 {
     Q_OBJECT;
@@ -35,14 +47,19 @@ class ResList : public QTEXTBROWSER
     // the docseq here. This has also the side-effect of making the
     // entry current (visible and highlighted), and only work if the
     // num is inside the current page or its immediate neighbours.
-    virtual bool getDoc(int docnum, Rcl::Doc &);
+    bool getDoc(int docnum, Rcl::Doc &);
 
-    virtual void setDocSource(RefCntr<DocSequence> source);
-    virtual QString getDescription(); // Printable actual query performed on db
-    virtual int getResCnt(); // Return total result list size
+    QString getDescription(); // Printable actual query performed on db
+    int getResCnt(); // Return total result list size
+    void setDocSource(RefCntr<DocSequence> ndocsource);
+    bool displayingHistory();
+    bool getTerms(vector<string>& terms, 
+		  vector<vector<string> >& groups, vector<int>& gslks);
+    list<string> expand(Rcl::Doc& doc);
+    int listId() const {return m_listId;}
 
  public slots:
-    virtual void resetSearch();
+    virtual void resetList();     // Erase current list
     virtual void doubleClicked(int, int);
     virtual void resPageUpOrBack(); // Page up pressed
     virtual void resPageDownOrNext(); // Page down pressed
@@ -59,6 +76,9 @@ class ResList : public QTEXTBROWSER
     virtual void append(const QString &text);
     // Only used for qt ver >=4 but seems we cant undef it
     virtual void selecChanged();
+    virtual void setDocSource();
+    virtual void setSortParams(const DocSeqSortSpec &spec);
+    virtual void setFilterParams(const DocSeqFiltSpec &spec);
 
  signals:
     void nextPageAvailable(bool);
@@ -82,14 +102,25 @@ class ResList : public QTEXTBROWSER
     virtual void showQueryDetails();
 
  private:
-    std::map<int,int>        m_pageParaToReldocnums;
-    RefCntr<DocSequence>     m_docSource;
-    std::vector<Rcl::Doc>    m_curDocs;
+    // Raw doc source
+    RefCntr<DocSequence>  m_baseDocSource;
+    // Possibly filtered/sorted docsource (the one displayed)
+    RefCntr<DocSequence>  m_docSource;
+    // Current sort and filtering parameters
+    DocSeqSortSpec        m_sortspecs;
+    DocSeqFiltSpec        m_filtspecs;
+    // Docs for current page
+    std::vector<Rcl::Doc> m_curDocs;
+    // First docnum (in m_docSource sequence) for current page
     int                m_winfirst;
+    // Translate from textedit paragraph number to relative
+    // docnum. Built while we insert text into the qtextedit
+    std::map<int,int>  m_pageParaToReldocnums;
     int                m_popDoc; // Docnum for the popup menu.
     int                m_curPvDoc;// Docnum for current preview
     int                m_lstClckMod; // Last click modifier. 
     list<int>          m_selDocs;
+    int                m_listId;
 
     virtual int docnumfromparnum(int);
     virtual int parnumfromdocnum(int);
@@ -99,6 +130,7 @@ class ResList : public QTEXTBROWSER
 	emit linkClicked(s, m_lstClckMod);
     };
     virtual RCLPOPUP *createPopupMenu(const QPoint& pos);
+    static int newListId();
 };
 
 
