@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: uiprefs_w.cpp,v 1.24 2008/05/05 20:24:55 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: uiprefs_w.cpp,v 1.26 2008/10/03 08:09:36 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -56,6 +56,7 @@ static char rcsid[] = "@(#$Id: uiprefs_w.cpp,v 1.24 2008/05/05 20:24:55 dockes E
 #include "recoll.h"
 #include "guiutils.h"
 #include "rcldb.h"
+#include "rclconfig.h"
 #include "pathut.h"
 #include "uiprefs_w.h"
 #include "viewaction_w.h"
@@ -105,7 +106,7 @@ void UIPrefsDialog::setFromPrefs()
     initStartSortCB->setChecked(prefs.startWithSortToolOpen);
     useDesktopOpenCB->setChecked(prefs.useDesktopOpen);
     keepSortCB->setChecked(prefs.keepSort);
-
+    previewHtmlCB->setChecked(prefs.previewHtml);
     // Query terms color
     qtermColorLE->setText(prefs.qtermcolor);
     
@@ -208,6 +209,7 @@ void UIPrefsDialog::accept()
     prefs.startWithSortToolOpen = initStartSortCB->isChecked();
     prefs.useDesktopOpen = useDesktopOpenCB->isChecked();
     prefs.keepSort = keepSortCB->isChecked();
+    prefs.previewHtml = previewHtmlCB->isChecked();
 
     prefs.syntAbsLen = syntlenSB->value();
     prefs.syntAbsCtx = syntctxSB->value();
@@ -363,9 +365,7 @@ void UIPrefsDialog::addExtraDbPB_clicked()
     }
     struct stat st1, st2;
     stat(dbdir.c_str(), &st1);
-    string rcldbdir;
-    if (rcldb) 
-	rcldbdir = rcldb->getDbDir();
+    string rcldbdir = RclConfig::getMainConfig()->getDbDir();
     stat(rcldbdir.c_str(), &st2);
     path_catslash(rcldbdir);
     fprintf(stderr, "rcldbdir: [%s]\n", rcldbdir.c_str());
