@@ -16,7 +16,7 @@
  */
 #ifndef _DOCSEQ_H_INCLUDED_
 #define _DOCSEQ_H_INCLUDED_
-/* @(#$Id: docseq.h,v 1.12 2007/06/19 08:36:24 dockes Exp $  (C) 2004 J.F.Dockes */
+/* @(#$Id: docseq.h,v 1.17 2008/09/29 11:33:55 dockes Exp $  (C) 2004 J.F.Dockes */
 #include <string>
 #include <list>
 #include <vector>
@@ -31,15 +31,51 @@ using std::vector;
 // A result list entry. 
 struct ResListEntry {
     Rcl::Doc doc;
-    int percent;
     string subHeader;
-    ResListEntry() : percent(0) {}
+};
+
+/** Sort specification. Will be made closer to the db interface one day */
+class DocSeqSortSpec {
+ public:
+    DocSeqSortSpec() : sortdepth(0) {}
+    enum Field {RCLFLD_MIMETYPE, RCLFLD_MTIME};
+    void addCrit(Field fld, bool desc = false) {
+	crits.push_back(fld);
+	dirs.push_back(desc);
+    }
+    bool isNotNull() {return sortdepth > 0;}
+
+    int sortdepth; // We only re-sort the first sortdepth most relevant docs
+    std::vector<Field> crits;
+    std::vector<bool> dirs;
+};
+
+/** Filtering spec. This is only used to filter by doc category for now, hence
+    the rather specialized interface */
+class DocSeqFiltSpec {
+ public:
+    DocSeqFiltSpec() {}
+    enum Crit {DSFS_MIMETYPE};
+    void orCrit(Crit crit, const string& value) {
+	crits.push_back(crit);
+	values.push_back(value);
+    }
+    std::vector<Crit> crits;
+    std::vector<string> values;
+    void reset() {crits.clear(); values.clear();}
+    bool isNotNull() {return crits.size() != 0;}
 };
 
 /** Interface for a list of documents coming from some source.
 
     The result list display data may come from different sources (ie:
     history or Db query), and be post-processed (DocSeqSorted).
+    Additional functionality like filtering/sorting can either be
+    obtained by stacking DocSequence objects (ie: sorting history), or
+    by native capability (ex: docseqdb can sort and filter). The
+    implementation might be nicer by using more sophisticated c++ with
+    multiple inheritance of sort and filter virtual interfaces, but
+    the current one will have to do for now...
 */
 class DocSequence {
  public:
@@ -50,17 +86,11 @@ class DocSequence {
      *
      * @param num document rank in sequence
      * @param doc return data
-     * @param percent this will be updated with the percentage of relevance, if
-     *        available, depending on the type of sequence. Return -1 in there 
-     *        to indicate that the specified document data is
-     *        unavailable but that there may be available data further
-     *        in the sequence
      * @param sh subheader to display before this result (ie: date change 
      *           inside history)
      * @return true if ok, false for error or end of data
      */
-    virtual bool getDoc(int num, Rcl::Doc &doc, int *percent, string *sh = 0) 
-	= 0;
+    virtual bool getDoc(int num, Rcl::Doc &doc, string *sh = 0) = 0;
 
     /** Get next page of documents. This accumulates entries into the result
      *  list (doesn't reset it). */
@@ -70,7 +100,7 @@ class DocSequence {
      *  The default is to return the input doc's abstract fields, but some 
      *  sequences can compute a better value (ie: docseqdb) */
     virtual string getAbstract(Rcl::Doc& doc) {
-	return doc.meta["abstract"];
+	return doc.meta[Rcl::Doc::keyabs];
     }
 
     /** Get estimated total count in results */
@@ -86,9 +116,17 @@ class DocSequence {
      * may have no associated search terms. Implement this for them. */
     virtual bool getTerms(vector<string>& terms, 
 			  vector<vector<string> >& groups, 
-			  vector<int>& gslks) const {
+			  vector<int>& gslks) 
+    {
 	terms.clear(); groups.clear(); gslks.clear(); return true;
     }
+    virtual list<string> expand(Rcl::Doc &) {list<string> e; return e;}
+
+    /** Optional functionality. Yeah, not nice */
+    virtual bool canFilter() {return false;}
+    virtual bool setFiltSpec(DocSeqFiltSpec &) {return false;}
+    virtual bool canSort() {return false;}
+    virtual bool setSortSpec(DocSeqSortSpec &) {return false;}
 
  private:
     string m_title;
