@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: docseqhist.cpp,v 1.2 2007/12/13 06:58:21 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: docseqhist.cpp,v 1.4 2008/09/29 08:59:20 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -23,9 +23,9 @@ static char rcsid[] = "@(#$Id: docseqhist.cpp,v 1.2 2007/12/13 06:58:21 dockes E
 
 #include "docseqhist.h"
 #include "rcldb.h"
+#include "fileudi.h"
 
-bool DocSequenceHistory::getDoc(int num, Rcl::Doc &doc, int *percent, 
-				string *sh) 
+bool DocSequenceHistory::getDoc(int num, Rcl::Doc &doc, string *sh) 
 {
     // Retrieve history list
     if (!m_hist)
@@ -46,8 +46,6 @@ bool DocSequenceHistory::getDoc(int num, Rcl::Doc &doc, int *percent,
     m_prevnum = num;
     while (skip--) 
 	m_it++;
-    if (percent)
-	*percent = 100;
     if (sh) {
 	if (m_prevtime < 0 || abs (float(m_prevtime) - float(m_it->unixtime)) > 86400) {
 	    m_prevtime = m_it->unixtime;
@@ -58,7 +56,14 @@ bool DocSequenceHistory::getDoc(int num, Rcl::Doc &doc, int *percent,
 	} else
 	    sh->erase();
     }
-    return m_db->getDoc(m_it->fn, m_it->ipath, doc, percent);
+    string udi;
+    make_udi(m_it->fn, m_it->ipath, udi);
+    bool ret = m_db->getDoc(udi, doc);
+    if (!ret) {
+	doc.url = string("file://") + m_it->fn;
+	doc.ipath = m_it->ipath;
+    }
+    return ret;
 }
 
 int DocSequenceHistory::getResCnt()
