@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: recollq.cpp,v 1.12 2007/12/13 06:58:21 dockes Exp $ (C) 2006 J.F.Dockes";
+static char rcsid[] = "@(#$Id: recollq.cpp,v 1.20 2008/10/13 08:23:36 dockes Exp $ (C) 2006 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -32,6 +32,7 @@ static char rcsid[] = "@(#$Id: recollq.cpp,v 1.12 2007/12/13 06:58:21 dockes Exp
 using namespace std;
 
 #include "rcldb.h"
+#include "rclquery.h"
 #include "rclconfig.h"
 #include "pathut.h"
 #include "rclinit.h"
@@ -40,6 +41,34 @@ using namespace std;
 #include "wasatorcl.h"
 #include "internfile.h"
 #include "wipedir.h"
+#include "transcode.h"
+
+bool dump_contents(RclConfig *rclconfig, string& tmpdir, Rcl::Doc& doc)
+{
+    string fn = doc.url.substr(7);
+    struct stat st;
+    if (stat(fn.c_str(), &st) != 0) {
+	cout << "No such file: " << fn << endl;
+	return true;
+    } 
+    if (tmpdir.empty() || access(tmpdir.c_str(), 0) < 0) {
+	string reason;
+	if (!maketmpdir(tmpdir, reason)) {
+	    cerr << "Cannot create temporary directory: "
+		 << reason << endl;
+	    return false;
+	}
+    }
+    wipedir(tmpdir);
+    FileInterner interner(fn, &st, rclconfig, tmpdir, &doc.mimetype);
+    if (interner.internfile(doc, doc.ipath)) {
+	cout << doc.text << endl;
+    } else {
+	cout << "Cant intern: " << fn << endl;
+    }
+    return true;
+}
+
 
 static char *thisprog;
 static char usage [] =
@@ -58,6 +87,9 @@ static char usage [] =
 "    -d also dump file contents\n"
 "    -n <cnt> limit the maximum number of results (0->no limit, default 2000)\n"
 "    -b : basic. Just output urls, no mime types or titles\n"
+"    -m : dump the whole document meta[] array\n"
+"    -S fld : sort by field name\n"
+"    -D : sort descending\n"
 ;
 static void
 Usage(void)
@@ -79,10 +111,16 @@ static int     op_flags;
 #define OPT_l     0x100
 #define OPT_q     0x200
 #define OPT_t     0x400
+#define OPT_m     0x800
+#define OPT_D     0x1000
+#define OPT_S     0x2000
+
 
 int recollq(RclConfig **cfp, int argc, char **argv)
 {
     string a_config;
+    string sortfield;
+
     int limit = 2000;
     thisprog = argv[0];
     argc--; argv++;
@@ -100,14 +138,19 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 		a_config = *(++argv);
 		argc--; goto b1;
             case 'd':   op_flags |= OPT_d; break;
+            case 'D':   op_flags |= OPT_D; break;
             case 'f':   op_flags |= OPT_f; break;
             case 'l':   op_flags |= OPT_l; break;
+            case 'm':   op_flags |= OPT_m; break;
 	    case 'n':	op_flags |= OPT_n; if (argc < 2)  Usage();
 		limit = atoi(*(++argv));
 		if (limit <= 0) limit = INT_MAX;
 		argc--; goto b1;
             case 'o':   op_flags |= OPT_o; break;
             case 'q':   op_flags |= OPT_q; break;
+	    case 'S':	op_flags |= OPT_S; if (argc < 2)  Usage();
+		sortfield = *(++argv);
+		argc--; goto b1;
             case 't':   op_flags |= OPT_t; break;
             default: Usage();   break;
             }
@@ -121,7 +164,6 @@ int recollq(RclConfig **cfp, int argc, char **argv)
     while (argc > 0) {
 	qs += string(" ") + *argv++;argc--;
     }
-
     Rcl::Db rcldb;
     string dbdir;
     string reason;
@@ -131,9 +173,24 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	fprintf(stderr, "Recoll init failed: %s\n", reason.c_str());
 	exit(1);
     }
+
+    {
+	string uq;
+	string charset = rclconfig->getDefCharset(true);
+	int ercnt;
+	if (!transcode(qs, uq, charset, "UTF-8", &ercnt)) {
+	    fprintf(stderr, "Can't convert command line args to utf-8\n");
+	    exit(1);
+	} else if (ercnt) {
+	    fprintf(stderr, "%d errors while converting arguments from %s "
+		    "to utf-8\n", ercnt, charset.c_str());
+	}
+	qs = uq;
+    }
+
+
     dbdir = rclconfig->getDbDir();
-    rcldb.open(dbdir,  rclconfig->getStopfile(),
-	       Rcl::Db::DbRO, Rcl::Db::QO_STEM);
+    rcldb.open(dbdir,  rclconfig->getStopfile(), Rcl::Db::DbRO);
 
     Rcl::SearchData *sd = 0;
 
@@ -164,10 +221,15 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	cerr << "Query string interpretation failed: " << reason << endl;
 	return 1;
     }
+    sd->setStemlang("english");
 
     RefCntr<Rcl::SearchData> rq(sd);
-    rcldb.setQuery(rq, Rcl::Db::QO_STEM);
-    int cnt = rcldb.getResCnt();
+    Rcl::Query query(&rcldb);
+    if (op_flags & OPT_S) {
+	query.setSortBy(sortfield, (op_flags & OPT_D) ? false : true);
+    }
+    query.setQuery(rq);
+    int cnt = query.getResCnt();
     if (!(op_flags & OPT_b)) {
 	cout << "Recoll query: " << rq->getDescription() << endl;
 	if (cnt <= limit)
@@ -178,47 +240,32 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 
     string tmpdir;
     for (int i = 0; i < limit; i++) {
-	int pc;
 	Rcl::Doc doc;
-	if (!rcldb.getDoc(i, doc, &pc))
+	if (!query.getDoc(i, doc))
 	    break;
 
 	if (op_flags & OPT_b) {
 	    cout << doc.url.c_str() << endl;
 	} else {
 	    char cpc[20];
-	    sprintf(cpc, "%d", pc);
+	    sprintf(cpc, "%d", doc.pc);
 	    cout 
 		<< doc.mimetype.c_str() << "\t"
 		<< "[" << doc.url.c_str() << "]" << "\t" 
-		<< "[" << doc.meta["title"].c_str() << "]" << "\t"
+		<< "[" << doc.meta[Rcl::Doc::keytt].c_str() << "]" << "\t"
 		<< doc.fbytes.c_str()   << "\tbytes" << "\t"
 		<<  endl;
-	}
-	if (op_flags & OPT_d) {
-	    string fn = doc.url.substr(7);
-	    struct stat st;
-	    if (stat(fn.c_str(), &st) != 0) {
-		cout << "No such file: " << fn << endl;
-		continue;
-	    } 
-	    if (tmpdir.empty() || access(tmpdir.c_str(), 0) < 0) {
-		string reason;
-		if (!maketmpdir(tmpdir, reason)) {
-		    cerr << "Cannot create temporary directory: "
-			 << reason << endl;
-		    return 1;
+	    if (op_flags & OPT_m) {
+		for (map<string,string>::const_iterator it = doc.meta.begin();
+		     it != doc.meta.end(); it++) {
+		    cout << it->first << " = " << it->second << endl;
 		}
 	    }
-	    wipedir(tmpdir);
-	    FileInterner interner(fn, &st, rclconfig, tmpdir, &doc.mimetype);
-	    if (interner.internfile(doc, doc.ipath)) {
-		cout << doc.text << endl;
-	    } else {
-		cout << "Cant intern: " << fn << endl;
-	    }
 	}
-	
+
+	if (op_flags & OPT_d) {
+	    dump_contents(rclconfig, tmpdir, doc);
+	}	
     }
 
     // Maybe clean up temporary directory
