@@ -16,7 +16,7 @@
  */
 #ifndef _SORTSEQ_H_INCLUDED_
 #define _SORTSEQ_H_INCLUDED_
-/* @(#$Id: sortseq.h,v 1.10 2007/01/19 15:22:50 dockes Exp $  (C) 2004 J.F.Dockes */
+/* @(#$Id: sortseq.h,v 1.13 2008/09/29 11:33:55 dockes Exp $  (C) 2004 J.F.Dockes */
 
 #include <vector>
 #include <string>
@@ -24,19 +24,6 @@
 #include "refcntr.h"
 #include "docseq.h"
 
-class DocSeqSortSpec {
- public:
-    DocSeqSortSpec() : sortwidth(0) {}
-    int sortwidth; // We only re-sort the first sortwidth most relevant docs
-    enum Field {RCLFLD_URL, RCLFLD_IPATH, RCLFLD_MIMETYPE, RCLFLD_MTIME};
-    void addCrit(Field fld, bool desc = false) {
-	crits.push_back(fld);
-	dirs.push_back(desc);
-    }
-    std::vector<Field> crits;
-    std::vector<bool> dirs;
-};
-
 /** 
  * A sorted sequence is created from the first N documents of another one, 
  * and sorts them according to the given criteria.
@@ -46,8 +33,10 @@ class DocSeqSorted : public DocSequence {
     DocSeqSorted(RefCntr<DocSequence> iseq, DocSeqSortSpec &sortspec, 
 		 const std::string &t);
     virtual ~DocSeqSorted() {}
-    virtual bool getDoc(int num, Rcl::Doc &doc, int *percent, string *sh = 0);
-    virtual int getResCnt() {return m_spec.sortwidth;}
+    virtual bool canSort() {return true;}
+    virtual bool setSortSpec(DocSeqSortSpec &sortspec);
+    virtual bool getDoc(int num, Rcl::Doc &doc, string *sh = 0);
+    virtual int getResCnt() {return m_spec.sortdepth;}
     virtual string getAbstract(Rcl::Doc& doc) {
 	return m_seq->getAbstract(doc);
     }
