@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: wasatorcl.cpp,v 1.13 2008/01/16 11:14:38 dockes Exp $ (C) 2006 J.F.Dockes";
+static char rcsid[] = "@(#$Id: wasatorcl.cpp,v 1.16 2008/10/07 06:52:57 dockes Exp $ (C) 2006 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@ using std::list;
 #include "debuglog.h"
 #include "smallut.h"
 #include "rclconfig.h"
+#include "refcntr.h"
 
 Rcl::SearchData *wasaStringToRcl(const string &qs, string &reason)
 {
@@ -56,6 +57,8 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
     Rcl::SearchData *sdata = new 
 	Rcl::SearchData(wasa->m_op == WasaQuery::OP_AND ? Rcl::SCLT_AND : 
 			Rcl::SCLT_OR);
+    LOGDEB2(("wasaQueryToRcl: %s chain\n", wasa->m_op == WasaQuery::OP_AND ? 
+	     "AND" : "OR"));
 
     WasaQuery::subqlist_t::iterator it;
     Rcl::SearchDataClause *nclause;
@@ -67,10 +70,14 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
 	default:
 	    LOGINFO(("wasaQueryToRcl: found bad NULL or AND q type in list\n"));
 	    continue;
-	case WasaQuery::OP_LEAF:
-
+	case WasaQuery::OP_LEAF: {
+	    LOGDEB2(("wasaQueryToRcl: leaf clause [%s]:[%s]\n", 
+		     (*it)->m_fieldspec.c_str(), (*it)->m_value.c_str()));
+	    unsigned int mods = (unsigned int)(*it)->m_modifiers;
 	    // Special cases (mime, category, dir filter ...). Not pretty.
-	    if (!stringicmp("mime", (*it)->m_fieldspec)) {
+	    if (!stringicmp("mime", (*it)->m_fieldspec) ||
+		!stringicmp("format", (*it)->m_fieldspec)
+		) {
 		sdata->addFiletype((*it)->m_value);
 		break;
 	    } 
@@ -95,8 +102,14 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
 	    } 
 
 	    if ((*it)->m_value.find_first_of(" \t\n\r") != string::npos) {
-		nclause = new Rcl::SearchDataClauseDist(Rcl::SCLT_PHRASE, 
-							(*it)->m_value, 0, 
+		int slack = (mods & WasaQuery::WQM_PHRASESLACK) ? 10 : 0;
+		Rcl::SClType tp = Rcl::SCLT_PHRASE;
+		if (mods & WasaQuery::WQM_PROX) {
+		    tp = Rcl::SCLT_NEAR;
+		    slack = 10;
+		}
+		nclause = new Rcl::SearchDataClauseDist(tp, (*it)->m_value,
+							slack,
 							(*it)->m_fieldspec);
 	    } else {
 		nclause = new Rcl::SearchDataClauseSimple(Rcl::SCLT_AND, 
@@ -112,9 +125,12 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
 		nclause->setModifiers(Rcl::SearchDataClause::SDCM_NOSTEMMING);
 	    }
 	    sdata->addClause(nclause);
+	}
 	    break;
-
+	    
 	case WasaQuery::OP_EXCL:
+	    LOGDEB2(("wasaQueryToRcl: excl clause [%s]:[%s]\n", 
+		     (*it)->m_fieldspec.c_str(), (*it)->m_value.c_str()));
 	    if (wasa->m_op != WasaQuery::OP_AND) {
 		LOGERR(("wasaQueryToRcl: negative clause inside OR list!\n"));
 		continue;
@@ -139,12 +155,16 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
 	    break;
 
 	case WasaQuery::OP_OR:
+	    LOGDEB2(("wasaQueryToRcl: OR clause [%s]:[%s]\n", 
+		     (*it)->m_fieldspec.c_str(), (*it)->m_value.c_str()));
 	    // Create a subquery.
 	    Rcl::SearchData *sub = wasaQueryToRcl(*it);
 	    if (sub == 0) {
 		continue;
 	    }
-	    nclause = new Rcl::SearchDataClauseSub(Rcl::SCLT_SUB, sub);
+	    nclause = 
+		new Rcl::SearchDataClauseSub(Rcl::SCLT_SUB, 
+					     RefCntr<Rcl::SearchData>(sub));
 	    if (nclause == 0) {
 		LOGERR(("wasaQueryToRcl: out of memory\n"));
 		return 0;
