@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: searchdata.cpp,v 1.21 2008/01/16 11:14:38 dockes Exp $ (C) 2006 J.F.Dockes";
+static char rcsid[] = "@(#$Id: searchdata.cpp,v 1.26 2008/10/14 07:50:13 dockes Exp $ (C) 2006 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -43,23 +43,46 @@ namespace Rcl {
 typedef  vector<SearchDataClause *>::iterator qlist_it_t;
 typedef  vector<SearchDataClause *>::const_iterator qlist_cit_t;
 
-bool SearchData::toNativeQuery(Rcl::Db &db, void *d, const string& stemlang)
+bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 {
     Xapian::Query xq;
     m_reason.erase();
 
+    if (m_query.size() < 1) {
+	m_reason = "empty query";
+	return false;
+    }
+
+    // It's not allowed to have a pure negative query and also it
+    // seems that Xapian doesn't like the first element to be AND_NOT
+    qlist_it_t itnotneg = m_query.end();
+    for (qlist_it_t it = m_query.begin(); it != m_query.end(); it++) {
+	if ((*it)->m_tp != SCLT_EXCL) {
+	    itnotneg = it;
+	    break;
+	}
+    }
+    if (itnotneg == m_query.end()) {
+	LOGERR(("SearchData::toNativeQuery: can't have all negative clauses"));
+	m_reason = "Can't have only negative clauses";
+	return false;
+    }
+    if ((*m_query.begin())->m_tp == SCLT_EXCL) 
+	iter_swap(m_query.begin(), itnotneg);
+
     // Walk the clause list translating each in turn and building the 
     // Xapian query tree
     for (qlist_it_t it = m_query.begin(); it != m_query.end(); it++) {
 	Xapian::Query nq;
-	if (!(*it)->toNativeQuery(db, &nq, stemlang)) {
+	if (!(*it)->toNativeQuery(db, &nq, m_stemlang)) {
 	    LOGERR(("SearchData::toNativeQuery: failed\n"));
 	    m_reason = (*it)->getReason();
 	    return false;
 	}	    
 
 	// If this structure is an AND list, must use AND_NOT for excl clauses.
-	// Else this is an OR list, and there can't be excl clauses
+	// Else this is an OR list, and there can't be excl clauses (checked by
+	// addClause())
 	Xapian::Query::op op;
 	if (m_tp == SCLT_AND) {
 	    op = (*it)->m_tp == SCLT_EXCL ? 
@@ -549,9 +572,9 @@ bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p,
     list<string> names;
     for (list<string>::iterator it = patterns.begin();
 	 it != patterns.end(); it++) {
-	// This relies on filenameWildExp not resetting and always
-	// adding to the input
-	db.filenameWildExp(*it, names);
+	list<string> more;
+	db.filenameWildExp(*it, more);
+	names.splice(names.end(), more);
     }
     // Build a query out of the matching file name terms.
     *qp = Xapian::Query(Xapian::Query::OP_OR, names.begin(), names.end());
@@ -608,10 +631,16 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p,
 }
 
 // Translate subquery
-bool SearchDataClauseSub::toNativeQuery(Rcl::Db &db, void *p, 
-					 const string& stemlang)
+bool SearchDataClauseSub::toNativeQuery(Rcl::Db &db, void *p, const string&)
 {
-    return m_sub->toNativeQuery(db, p, stemlang);
+    return m_sub->toNativeQuery(db, p);
+}
+
+bool SearchDataClauseSub::getTerms(vector<string>& terms, 
+				   vector<vector<string> >& groups,
+				   vector<int>& gslks) const
+{
+    return m_sub.getconstptr()->getTerms(terms, groups, gslks);
 }
 
 } // Namespace Rcl
