@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: smallut.cpp,v 1.28 2008/05/08 09:57:29 dockes Exp $ (C) 2004 J.F.Dockes";
+static char rcsid[] = "@(#$Id: smallut.cpp,v 1.34 2008/10/08 16:15:22 dockes Exp $ (C) 2004 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@ static char rcsid[] = "@(#$Id: smallut.cpp,v 1.28 2008/05/08 09:57:29 dockes Exp
 #include <string>
 
 #include "smallut.h"
+#include "utf8iter.h"
 
 #ifndef NO_NAMESPACES
 using namespace std;
@@ -76,7 +77,12 @@ void stringtolower(string& io)
 	it++;
     }
 }
-
+string stringtolower(const string& i)
+{
+    string o = i;
+    stringtolower(o);
+    return o;
+}
 extern int stringisuffcmp(const string& s1, const string& s2)
 {
     string::const_reverse_iterator r1 = s1.rbegin(), re1 = s1.rend(),
@@ -185,7 +191,7 @@ template <class T> bool stringToStrings(const string &s, T &tokens)
 		continue;
 	      case INQUOTE: 
 		tokens.push_back(current);
-		current = "";
+		current.clear();
 		state = SPACE;
 		continue;
 	      case ESCAPE:
@@ -220,7 +226,7 @@ template <class T> bool stringToStrings(const string &s, T &tokens)
 		  continue;
 	      case TOKEN: 
 		tokens.push_back(current);
-		current = "";
+		current.clear();
 		state = SPACE;
 		continue;
 	      case INQUOTE: 
@@ -298,6 +304,10 @@ void stringsToString(const vector<string> &tokens, string &s)
 {
     stringsToString<vector<string> >(tokens, s);
 }
+void stringsToString(const set<string> &tokens, string &s)
+{
+    stringsToString<set<string> >(tokens, s);
+}
 
 void stringToTokens(const string& str, list<string>& tokens,
 		    const string& delims, bool skipinit)
@@ -336,14 +346,14 @@ void trimstring(string &s, const char *ws)
 {
     string::size_type pos = s.find_first_not_of(ws);
     if (pos == string::npos) {
-	s = "";
+	s.clear();
 	return;
     }
-    s.replace(0, pos, "");
+    s.replace(0, pos, string());
 
     pos = s.find_last_not_of(ws);
     if (pos != string::npos && pos != s.length()-1)
-	s.replace(pos+1, string::npos, "");
+	s.replace(pos+1, string::npos, string());
 }
 
 // Remove some chars and replace them with spaces
@@ -374,7 +384,7 @@ string neutchars(const string &str, string delims)
  * we have enough, this would be cleanly utf8-aware but would remove 
  * punctuation */
 static const string SEPAR = " \t\n\r-:.;,/[]{}";
-string truncate_to_word(string & input, string::size_type maxlen)
+string truncate_to_word(const string &input, string::size_type maxlen)
 {
     string output;
     if (input.length() <= maxlen) {
@@ -398,6 +408,19 @@ string truncate_to_word(string & input, string::size_type maxlen)
     return output;
 }
 
+void utf8truncate(string &s, int maxlen)
+{
+    if (s.size() <= string::size_type(maxlen))
+	return;
+    Utf8Iter iter(s);
+    int pos = 0;
+    while (iter++ != string::npos) 
+	if (iter.getBpos() < string::size_type(maxlen))
+	    pos = iter.getBpos();
+
+    s.erase(pos);
+}
+
 // Escape things that would look like markup
 string escapeHtml(const string &in)
 {
@@ -563,6 +586,9 @@ float Chrono::secs(int frozen)
 #else
 
 #include <string>
+using namespace std;
+#include <iostream>
+
 #include "smallut.h"
 
 struct spair {
@@ -618,12 +644,21 @@ int main(int argc, char **argv)
 	}
 	printf("\n");
     }
-#else
+#elif 0
     for (int i = 0; i < nsuffpairs; i++) {
 	int c = stringisuffcmp(suffpairs[i].s1, suffpairs[i].s2);
 	printf("[%s] %s [%s] \n", suffpairs[i].s1, 
 	       c == 0 ? "matches" : c < 0 ? "<" : ">", suffpairs[i].s2);
     }
+#elif 0
+    std::string testit("\303\251l\303\251gant");
+    for (int sz = 10; sz >= 0; sz--) {
+	utf8truncate(testit, sz);
+	cout << testit << endl;
+    }
+#elif 1
+    std::string testit("ligne\ndeuxieme ligne\r3eme ligne\r\n");
+    cout << "[" << neutchars(testit, "\r\n") << "]" << endl;
 #endif
 
 }
