@@ -16,17 +16,19 @@
  */
 #ifndef _SMALLUT_H_INCLUDED_
 #define _SMALLUT_H_INCLUDED_
-/* @(#$Id: smallut.h,v 1.28 2008/05/08 09:57:29 dockes Exp $  (C) 2004 J.F.Dockes */
+/* @(#$Id: smallut.h,v 1.31 2008/10/08 16:15:22 dockes Exp $  (C) 2004 J.F.Dockes */
 #include <string>
 #include <list>
 #include <vector>
 #include <map>
+#include <set>
 
 #ifndef NO_NAMESPACES
 using std::string;
 using std::list;
 using std::vector;
 using std::map;
+using std::set;
 #endif /* NO_NAMESPACES */
 
 // Note these are all ascii routines
@@ -34,6 +36,7 @@ extern int stringicmp(const string& s1, const string& s2);
 extern int stringlowercmp(const string& alreadylower, const string& s2);
 extern int stringuppercmp(const string& alreadyupper, const string& s2); 
 extern void stringtolower(string& io);
+extern string stringtolower(const string& io);
 // Is one string the end part of the other ?
 extern int stringisuffcmp(const string& s1, const string& s2);
 
@@ -54,6 +57,7 @@ extern bool stringToStrings(const string &s, vector<string> &tokens);
  */
 extern void stringsToString(const list<string> &tokens, string &s);
 extern void stringsToString(const vector<string> &tokens, string &s);
+extern void stringsToString(const set<string> &tokens, string &s);
 
 /**
  * Split input string. No handling of quoting
@@ -81,7 +85,10 @@ extern string escapeShell(const string &str);
 
 /** Truncate a string to a given maxlength, avoiding cutting off midword
  *  if reasonably possible. */
-extern string truncate_to_word(string &input, string::size_type maxlen);
+extern string truncate_to_word(const string &input, string::size_type maxlen);
+
+/** Truncate in place in an utf8-legal way */
+extern void utf8truncate(string &s, int maxlen);
 
 /** Small utility to substitute printf-like percents cmds in a string */
 bool pcSubst(const string& in, string& out, map<char, string>& subs);
